@@ -107,9 +107,11 @@ function pageinfo() {
     $info['isadmin']   = false;
     $info['ismanager'] = false;
     if(isset($_SERVER['REMOTE_USER'])) {
+        $sub = new Subscription();
+
         $info['userinfo']   = $USERINFO;
         $info['perm']       = auth_quickaclcheck($ID);
-        $info['subscribed'] = get_info_subscribed();
+        $info['subscribed'] = $sub->user_subscription();
         $info['client']     = $_SERVER['REMOTE_USER'];
 
         if($info['perm'] == AUTH_ADMIN) {
@@ -309,7 +311,11 @@ function breadcrumbs() {
  *
  * This is run on a ID before it is outputted somewhere
  * currently used to replace the colon with something else
- * on Windows systems and to have proper URL encoding
+ * on Windows (non-IIS) systems and to have proper URL encoding
+ *
+ * See discussions at https://github.com/splitbrain/dokuwiki/pull/84 and
+ * https://github.com/splitbrain/dokuwiki/pull/173 why we use a whitelist of
+ * unaffected servers instead of blacklisting affected servers here.
  *
  * Urlencoding is ommitted when the second parameter is false
  *
@@ -320,7 +326,8 @@ function idfilter($id, $ue = true) {
     if($conf['useslash'] && $conf['userewrite']) {
         $id = strtr($id, ':', '/');
     } elseif(strtoupper(substr(PHP_OS, 0, 3)) === 'WIN' &&
-        $conf['userewrite']
+        $conf['userewrite'] &&
+        strpos($_SERVER['SERVER_SOFTWARE'], 'Microsoft-IIS') === false
     ) {
         $id = strtr($id, ':', ';');
     }
@@ -429,6 +436,10 @@ function exportlink($id = '', $format = 'raw', $more = '', $abs = false, $sep =
 function ml($id = '', $more = '', $direct = true, $sep = '&amp;', $abs = false) {
     global $conf;
     if(is_array($more)) {
+        // add token for resized images
+        if($more['w'] || $more['h']){
+            $more['tok'] = media_get_token($id,$more['w'],$more['h']);
+        }
         // strip defaults for shorter URLs
         if(isset($more['cache']) && $more['cache'] == 'cache') unset($more['cache']);
         if(!$more['w']) unset($more['w']);
@@ -436,6 +447,14 @@ function ml($id = '', $more = '', $direct = true, $sep = '&amp;', $abs = false)
         if(isset($more['id']) && $direct) unset($more['id']);
         $more = buildURLparams($more, $sep);
     } else {
+        $matches = array();
+        if (preg_match_all('/\b(w|h)=(\d*)\b/',$more,$matches,PREG_SET_ORDER)){
+            $resize = array('w'=>0, 'h'=>0);
+            foreach ($matches as $match){
+                $resize[$match[1]] = $match[2];
+            }
+            $more .= $sep.'tok='.media_get_token($id,$resize['w'],$resize['h']);
+        }
         $more = str_replace('cache=cache', '', $more); //skip default
         $more = str_replace(',,', ',', $more);
         $more = str_replace(',', $sep, $more);
@@ -770,11 +789,19 @@ function unlock($id) {
 /**
  * convert line ending to unix format
  *
+ * also makes sure the given text is valid UTF-8
+ *
  * @see    formText() for 2crlf conversion
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function cleanText($text) {
     $text = preg_replace("/(\015\012)|(\015)/", "\012", $text);
+
+    // if the text is not valid UTF-8 we simply assume latin1
+    // this won't break any worse than it breaks with the wrong encoding
+    // but might actually fix the problem in many cases
+    if(!utf8_check($text)) $text = utf8_encode($text);
+
     return $text;
 }
 
@@ -1103,90 +1130,31 @@ function saveOldRevision($id) {
  * @author Andreas Gohr <andi@splitbrain.org>
  */
 function notify($id, $who, $rev = '', $summary = '', $minor = false, $replace = array()) {
-    global $lang;
     global $conf;
-    global $INFO;
-    global $DIFF_INLINESTYLES;
 
     // decide if there is something to do, eg. whom to mail
     if($who == 'admin') {
         if(empty($conf['notify'])) return false; //notify enabled?
-        $text = rawLocale('mailtext');
-        $to   = $conf['notify'];
-        $bcc  = '';
+        $tpl = 'mailtext';
+        $to  = $conf['notify'];
     } elseif($who == 'subscribers') {
-        if(!$conf['subscribers']) return false; //subscribers enabled?
+        if(!actionOK('subscribe')) return false; //subscribers enabled?
         if($conf['useacl'] && $_SERVER['REMOTE_USER'] && $minor) return false; //skip minors
         $data = array('id' => $id, 'addresslist' => '', 'self' => false);
         trigger_event(
             'COMMON_NOTIFY_ADDRESSLIST', $data,
-            'subscription_addresslist'
+            array(new Subscription(), 'notifyaddresses')
         );
-        $bcc = $data['addresslist'];
-        if(empty($bcc)) return false;
-        $to   = '';
-        $text = rawLocale('subscr_single');
-    } elseif($who == 'register') {
-        if(empty($conf['registernotify'])) return false;
-        $text = rawLocale('registermail');
-        $to   = $conf['registernotify'];
-        $bcc  = '';
+        $to = $data['addresslist'];
+        if(empty($to)) return false;
+        $tpl = 'subscr_single';
     } else {
         return false; //just to be safe
     }
 
-    // prepare replacements (keys not set in hrep will be taken from trep)
-    $trep = array(
-        'NEWPAGE' => wl($id, '', true, '&'),
-        'PAGE'    => $id,
-        'SUMMARY' => $summary
-    );
-    $trep = array_merge($trep, $replace);
-    $hrep = array();
-
     // prepare content
-    if($who == 'register') {
-        $subject = $lang['mail_new_user'].' '.$summary;
-    } elseif($rev) {
-        $subject         = $lang['mail_changed'].' '.$id;
-        $trep['OLDPAGE'] = wl($id, "rev=$rev", true, '&');
-        $old_content     = rawWiki($id, $rev);
-        $new_content     = rawWiki($id);
-        $df              = new Diff(explode("\n", $old_content),
-                                    explode("\n", $new_content));
-        $dformat         = new UnifiedDiffFormatter();
-        $tdiff           = $dformat->format($df);
-
-        $DIFF_INLINESTYLES = true;
-        $hdf               = new Diff(explode("\n", hsc($old_content)),
-                                      explode("\n", hsc($new_content)));
-        $dformat           = new InlineDiffFormatter();
-        $hdiff             = $dformat->format($hdf);
-        $hdiff             = '<table>'.$hdiff.'</table>';
-        $DIFF_INLINESTYLES = false;
-    } else {
-        $subject         = $lang['mail_newpage'].' '.$id;
-        $trep['OLDPAGE'] = '---';
-        $tdiff           = rawWiki($id);
-        $hdiff           = nl2br(hsc($tdiff));
-    }
-    $trep['DIFF'] = $tdiff;
-    $hrep['DIFF'] = $hdiff;
-
-    // send mail
-    $mail = new Mailer();
-    $mail->to($to);
-    $mail->bcc($bcc);
-    $mail->subject($subject);
-    $mail->setBody($text, $trep, $hrep);
-    if($who == 'subscribers') {
-        $mail->setHeader(
-            'List-Unsubscribe',
-            '<'.wl($id, array('do'=> 'subscribe'), true, '&').'>',
-            false
-        );
-    }
-    return $mail->send();
+    $subscription = new Subscription();
+    return $subscription->send_diff($to, $tpl, $id, $rev, $summary);
 }
 
 /**
@@ -1226,27 +1194,6 @@ function getGoogleQuery() {
     return $q;
 }
 
-/**
- * Try to set correct locale
- *
- * @deprecated No longer used
- * @author     Andreas Gohr <andi@splitbrain.org>
- */
-function setCorrectLocale() {
-    global $conf;
-    global $lang;
-
-    $enc = strtoupper($lang['encoding']);
-    foreach($lang['locales'] as $loc) {
-        //try locale
-        if(@setlocale(LC_ALL, $loc)) return;
-        //try loceale with encoding
-        if(@setlocale(LC_ALL, "$loc.$enc")) return;
-    }
-    //still here? try to set from environment
-    @setlocale(LC_ALL, "");
-}
-
 /**
  * Return the human readable size of a file
  *
@@ -1603,18 +1550,50 @@ function valid_input_set($param, $valid_values, $array, $exc = '') {
 
 /**
  * Read a preference from the DokuWiki cookie
+ * (remembering both keys & values are urlencoded)
  */
 function get_doku_pref($pref, $default) {
-    if(strpos($_COOKIE['DOKU_PREFS'], $pref) !== false) {
+    $enc_pref = urlencode($pref);
+    if(strpos($_COOKIE['DOKU_PREFS'], $enc_pref) !== false) {
         $parts = explode('#', $_COOKIE['DOKU_PREFS']);
         $cnt   = count($parts);
         for($i = 0; $i < $cnt; $i += 2) {
-            if($parts[$i] == $pref) {
-                return $parts[$i + 1];
+            if($parts[$i] == $enc_pref) {
+                return urldecode($parts[$i + 1]);
             }
         }
     }
     return $default;
 }
 
+/**
+ * Add a preference to the DokuWiki cookie
+ * (remembering $_COOKIE['DOKU_PREFS'] is urlencoded)
+ */
+function set_doku_pref($pref, $val) {
+    global $conf;
+    $orig = get_doku_pref($pref, false);
+    $cookieVal = '';
+
+    if($orig && ($orig != $val)) {
+        $parts = explode('#', $_COOKIE['DOKU_PREFS']);
+        $cnt   = count($parts);
+        // urlencode $pref for the comparison
+        $enc_pref = rawurlencode($pref);
+        for($i = 0; $i < $cnt; $i += 2) {
+            if($parts[$i] == $enc_pref) {
+                $parts[$i + 1] = rawurlencode($val);
+                break;
+            }
+        }
+        $cookieVal = implode('#', $parts);
+    } else if (!$orig) {
+        $cookieVal = ($_COOKIE['DOKU_PREFS'] ? $_COOKIE['DOKU_PREFS'].'#' : '').rawurlencode($pref).'#'.rawurlencode($val);
+    }
+
+    if (!empty($cookieVal)) {
+        setcookie('DOKU_PREFS', $cookieVal, time()+365*24*3600, DOKU_BASE, '', ($conf['securecookie'] && is_ssl()));
+    }
+}
+
 //Setup VIM: ex: et ts=2 :
