@@ -55,7 +55,7 @@ $lang['current']               = 'huidige';
 $lang['line']                  = 'Streak';
 $lang['youarehere']            = 'Jy is hier';
 $lang['by']                    = 'by';
-$lang['restored']              = 'Het terug gegaan na vroeëre weergawe';
+$lang['restored']              = 'Het terug gegaan na vroeëre weergawe (%s)';
 $lang['summary']               = 'Voorskou';
 $lang['qb_bold']               = 'Vetdruk';
 $lang['qb_italic']             = 'Skuinsdruk';
