@@ -92,6 +92,7 @@ $lang['searchmedia_in']        = 'ابحث في %s';
 $lang['txt_upload']            = 'اختر ملفاً للرفع';
 $lang['txt_filename']          = 'رفع كـ (اختياري)';
 $lang['txt_overwrt']           = 'اكتب على ملف موجود';
+$lang['maxuploadsize']         = 'الحجم الاقصى %s للملف';
 $lang['lockedby']              = 'مقفلة حاليا لـ';
 $lang['lockexpire']            = 'ينتهي القفل في';
 $lang['js']['willexpire']      = 'سينتهي قفل تحرير هذه الصفحه خلال دقيقة.\nلتجنب التعارض استخدم زر المعاينة لتصفير مؤقت القفل.';
@@ -180,7 +181,7 @@ $lang['lastmod']               = 'آخر تعديل';
 $lang['by']                    = 'بواسطة';
 $lang['deleted']               = 'حذفت';
 $lang['created']               = 'اُنشئت';
-$lang['restored']              = 'استعيدت نسخة قديمة';
+$lang['restored']              = 'استعيدت نسخة قديمة (%s)';
 $lang['external_edit']         = 'تحرير خارجي';
 $lang['summary']               = 'ملخص التحرير';
 $lang['noflash']               = 'تحتاج إلى<a href="http://www.adobe.com/products/flashplayer/">ملحق فلاش أدوبي</a> لعرض هذا المحتوى.';
@@ -190,6 +191,7 @@ $lang['user_tools']            = 'أدوات المستخدم';
 $lang['site_tools']            = 'أدوات الموقع';
 $lang['page_tools']            = 'أدوات الصفحة';
 $lang['skip_to_content']       = 'تجاوز إلى المحتوى';
+$lang['sidebar']               = 'العمود الجانبي';
 $lang['mail_newpage']          = 'إضافة صفحة:';
 $lang['mail_changed']          = 'تعديل صفحة:';
 $lang['mail_subscribe_list']   = 'صفحات غيرت في النطاق:';
@@ -256,8 +258,6 @@ $lang['subscr_m_unsubscribe']  = 'ألغ الاشتراك';
 $lang['subscr_m_subscribe']    = 'اشترك';
 $lang['subscr_m_receive']      = 'استقبال';
 $lang['subscr_style_every']    = 'بريدا على كل تغيير';
-$lang['subscr_style_digest']   = 'بريد ملخص عن تغييرات كل صفحة';
-$lang['subscr_style_list']     = 'قائمة بالصفحات المتغيرة منذ آخر بريد';
 $lang['authmodfailed']         = 'إعدادات تصريح فاسدة، يرجى مراسلة المدير.';
 $lang['authtempfail']          = 'تصريح المشترك غير متوفر مؤقتاً، إن استمرت هذه الحالة يرجى مراسلة المدير';
 $lang['authpwdexpire']         = 'ستنتهي صلاحية كلمة السر في %d . عليك بتغييرها سريعا.';
