@@ -37,7 +37,7 @@ $lang['btn_admin']             = 'Настройки';
 $lang['btn_update']            = 'Актуализиране';
 $lang['btn_delete']            = 'Изтриване';
 $lang['btn_back']              = 'Назад';
-$lang['btn_backlink']          = 'Обратни препратки';
+$lang['btn_backlink']          = 'Какво сочи насам';
 $lang['btn_backtomedia']       = 'Назад към избора на файл';
 $lang['btn_subscribe']         = 'Абонаменти';
 $lang['btn_profile']           = 'Профил';
@@ -190,7 +190,7 @@ $lang['lastmod']               = 'Последна промяна';
 $lang['by']                    = 'от';
 $lang['deleted']               = 'изтрита';
 $lang['created']               = 'създадена';
-$lang['restored']              = 'възстановена предишна версия';
+$lang['restored']              = 'възстановена предишна версия (%s)';
 $lang['external_edit']         = 'външна редакция';
 $lang['summary']               = 'Обобщение';
 $lang['noflash']               = 'Необходим е <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> за изобразяване на съдържанието.';
@@ -200,6 +200,7 @@ $lang['user_tools']            = 'Инструменти за потребите
 $lang['site_tools']            = 'Инструменти за сайта';
 $lang['page_tools']            = 'Инструменти за страници';
 $lang['skip_to_content']       = 'към съдържанието';
+$lang['sidebar']               = 'Странична лента';
 
 $lang['mail_newpage']          = 'добавена страница: ';
 $lang['mail_changed']          = 'променена страница: ';
@@ -298,16 +299,19 @@ $lang['i_confexists']          = '<code>%s</code> вече съществува'
 $lang['i_writeerr']            = '<code>%s</code> не можа да бъде създаден. Трябва да проверите правата за достъп до директорията/файла и да създадете файла ръчно.';
 $lang['i_badhash']             = 'Файлът dokuwiki.php не може да бъде разпознат или е променен (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - непозволена или празна стойност';
-$lang['i_success']             = 'Настройването приключи успешно. Вече можете да изтриете файла install.php. Продължете към <a href="doku.php">Вашето ново DokuWiki</a>.';
+$lang['i_success']             = 'Настройването приключи успешно. Вече можете да изтриете файла install.php. Продължете към <a href="doku.php?id=wiki:welcome">Вашето ново DokuWiki</a>.';
 
-$lang['i_failure']             = 'Възникнаха грешки при записването на файловете с настройки. Вероятно ще се наложи да ги поправите ръчно, 
-                                  за да можете да ползвате <a href="doku.php">Вашето ново DokuWiki</a>.';
+$lang['i_failure']             = 'Възникнаха грешки при записването на файловете с настройки. Вероятно ще се наложи да ги поправите ръчно,
+                                  за да можете да ползвате <a href="doku.php?id=wiki:welcome">Вашето ново DokuWiki</a>.';
 $lang['i_policy']              = 'Първоначална политика за достъп';
 $lang['i_pol0']                = 'Отворено Wiki (всеки може да чете, пише и качва)';
 $lang['i_pol1']                = 'Публично Wiki (всеки може да чете, само регистрирани пишат и качват)';
 $lang['i_pol2']                = 'Затворено Wiki (само регистрирани четат, пишат и качват)';
 $lang['i_retry']               = 'Повторен опит';
 $lang['i_license']             = 'Моля, изберете лиценз под който желаете да публикувате съдържанието:';
+$lang['i_license_none']        = 'Без показване на информация относно лиценза';
+$lang['i_pop_field']           = 'Моля, помогнете за усъвършенстването на DokuWiki:';
+$lang['i_pop_label']           = 'Изпращане на анонимна информация до разработчиците на DokuWiki, веднъж седмично';
 
 $lang['recent_global']         = 'В момента преглеждате промените в именно пространство <b>%s</b>. Може да прегледате и <a href="%s">промените в цялото Wiki</a>.';
 $lang['years']                 = 'преди %d години';
