@@ -25,6 +25,8 @@
  * @author skimpax@gmail.com
  * @author Yannick Aure <yannick.aure@gmail.com>
  * @author Olivier DUVAL <zorky00@gmail.com>
+ * @author Anael Mobilia <contrib@anael.eu>
+ * @author Bruno Veilleux <bruno.vey@gmail.com>
  */
 $lang['encoding']              = 'utf-8';
 $lang['direction']             = 'ltr';
@@ -73,17 +75,17 @@ $lang['user']                  = 'Utilisateur';
 $lang['pass']                  = 'Mot de passe';
 $lang['newpass']               = 'Nouveau mot de passe';
 $lang['oldpass']               = 'Mot de passe actuel';
-$lang['passchk']               = 'Répéter nouveau mot de passe';
+$lang['passchk']               = 'Répétez le mot de passe';
 $lang['remember']              = 'Mémoriser';
 $lang['fullname']              = 'Nom';
 $lang['email']                 = 'Adresse de courriel';
 $lang['profile']               = 'Profil utilisateur';
 $lang['badlogin']              = 'L\'utilisateur ou le mot de passe est incorrect.';
 $lang['minoredit']             = 'Modification mineure';
-$lang['draftdate']             = 'Brouillon auto-enregistré le';
+$lang['draftdate']             = 'Brouillon enregistré de manière automatique le';
 $lang['nosecedit']             = 'La page a changé entre temps, les informations de la section sont obsolètes ; la page complète a été chargée à la place.';
 $lang['regmissing']            = 'Désolé, vous devez remplir tous les champs.';
-$lang['reguexists']            = 'Désolé, ce nom d\'utilisateur est déjà pris.';
+$lang['reguexists']            = 'Désolé, ce nom d\'utilisateur est déjà utilisé.';
 $lang['regsuccess']            = 'L\'utilisateur a été créé. Le mot de passe a été expédié par courriel.';
 $lang['regsuccess2']           = 'L\'utilisateur a été créé.';
 $lang['regmailfail']           = 'Il semble y avoir un problème à l\'envoi du courriel. Contactez l\'administrateur.';
@@ -92,94 +94,94 @@ $lang['regbadpass']            = 'Les deux mots de passe fournis sont différent
 $lang['regpwmail']             = 'Votre mot de passe DokuWiki';
 $lang['reghere']               = 'Vous n\'avez pas encore de compte ? Enregistrez-vous ici ';
 $lang['profna']                = 'Ce wiki ne permet pas de modifier les profils';
-$lang['profnochange']          = 'Pas de changement, rien à faire.';
+$lang['profnochange']          = 'Pas de modification, rien à faire.';
 $lang['profnoempty']           = 'Un nom ou une adresse de courriel vide n\'est pas permis.';
 $lang['profchanged']           = 'Mise à jour du profil réussie.';
-$lang['pwdforget']             = 'Mot de passe oublié ? Faites-vous envoyer votre mot de passe ';
+$lang['pwdforget']             = 'Mot de passe oublié ? Obtenez-en un nouveau';
 $lang['resendna']              = 'Ce wiki ne permet pas le renvoi de mot de passe.';
 $lang['resendpwd']             = 'Définir un nouveau mot de passe pour';
 $lang['resendpwdmissing']      = 'Désolé, vous devez remplir tous les champs.';
-$lang['resendpwdnouser']       = 'Désolé, cet utilisateur est introuvable dans notre base.';
-$lang['resendpwdbadauth']      = 'Désolé, ce code d\'authentification est invalide. Assurez-vous d\'avoir utilisé le lien de confirmation.';
-$lang['resendpwdconfirm']      = 'Un lien de confirmation vous a été envoyé par courriel.';
+$lang['resendpwdnouser']       = 'Désolé, cet utilisateur n\'existe pas dans notre base de données.';
+$lang['resendpwdbadauth']      = 'Désolé, ce code d\'authentification est invalide. Assurez-vous d\'avoir utilisé le lien de confirmation intégral.';
+$lang['resendpwdconfirm']      = 'Un lien de confirmation vous a été expédié par courriel.';
 $lang['resendpwdsuccess']      = 'Votre nouveau mot de passe vous a été expédié par courriel.';
-$lang['license']               = 'Sauf mention contraire, le contenu de ce wiki est placé sous la licence suivante :';
+$lang['license']               = 'Sauf mention contraire, le contenu de ce wiki est placé sous les termes de la licence suivante :';
 $lang['licenseok']             = 'Note : En modifiant cette page, vous acceptez que le contenu soit placé sous les termes de la licence suivante :';
 $lang['searchmedia']           = 'Chercher le nom de fichier :';
 $lang['searchmedia_in']        = 'Chercher dans %s';
 $lang['txt_upload']            = 'Sélectionnez un fichier à envoyer ';
-$lang['txt_filename']          = 'Donnez un « wikiname » (optionnel) ';
-$lang['txt_overwrt']           = 'Écraser le fichier cible';
-$lang['maxuploadsize']         = 'Téléverser max. %s par fichier';
+$lang['txt_filename']          = 'Envoyer en tant que (optionnel) ';
+$lang['txt_overwrt']           = 'Écraser le fichier cible (s\'il existe)';
+$lang['maxuploadsize']         = 'Taille d\'envoi maximale : %s par fichier';
 $lang['lockedby']              = 'Actuellement bloqué par';
 $lang['lockexpire']            = 'Le blocage expire à';
-$lang['js']['willexpire']      = 'Votre verrouillage pour la modification de cette page expire dans une minute.\nPour éviter les conflits, utilisez le bouton « Aperçu » pour réinitialiser le minuteur.';
+$lang['js']['willexpire']      = 'Votre blocage pour la modification de cette page expire dans une minute.\nPour éviter les conflits, utilisez le bouton « Aperçu » pour réinitialiser le minuteur.';
 $lang['js']['notsavedyet']     = 'Les modifications non enregistrées seront perdues. Voulez-vous vraiment continuer ?';
 $lang['js']['searchmedia']     = 'Chercher des fichiers';
-$lang['js']['keepopen']        = 'Gardez cette fenêtre toujours ouverte';
-$lang['js']['hidedetails']     = 'Masquer détails';
+$lang['js']['keepopen']        = 'Toujours conserver cette fenêtre ouverte';
+$lang['js']['hidedetails']     = 'Masquer les détails';
 $lang['js']['mediatitle']      = 'Paramètres de lien';
 $lang['js']['mediadisplay']    = 'Type de lien';
 $lang['js']['mediaalign']      = 'Alignement';
-$lang['js']['mediasize']       = 'Taille d\'image';
+$lang['js']['mediasize']       = 'Taille de l\'image';
 $lang['js']['mediatarget']     = 'Cible du lien';
 $lang['js']['mediaclose']      = 'Fermer';
 $lang['js']['mediainsert']     = 'Insérer';
 $lang['js']['mediadisplayimg'] = 'Afficher l\'image.';
 $lang['js']['mediadisplaylnk'] = 'N\'afficher que le lien.';
 $lang['js']['mediasmall']      = 'Petite taille';
-$lang['js']['mediamedium']     = 'taille moyenne';
+$lang['js']['mediamedium']     = 'Taille moyenne';
 $lang['js']['medialarge']      = 'Grande taille';
-$lang['js']['mediaoriginal']   = 'taille d\'origine';
+$lang['js']['mediaoriginal']   = 'Taille originelle';
 $lang['js']['medialnk']        = 'Lien vers la page de détail';
 $lang['js']['mediadirect']     = 'Lien direct vers l\'original';
 $lang['js']['medianolnk']      = 'Aucun lien';
 $lang['js']['medianolink']     = 'Ne pas lier l\'image';
-$lang['js']['medialeft']       = 'Aligner l\'image sur la gauche.';
-$lang['js']['mediaright']      = 'Aligner l\'image sur la droite.';
-$lang['js']['mediacenter']     = 'Centrer l\'image';
+$lang['js']['medialeft']       = 'Aligner l\'image à gauche.';
+$lang['js']['mediaright']      = 'Aligner l\'image à droite.';
+$lang['js']['mediacenter']     = 'Centrer l\'image.';
 $lang['js']['medianoalign']    = 'Ne pas aligner.';
 $lang['js']['nosmblinks']      = 'Les liens vers les partages Windows ne fonctionnent qu\'avec Microsoft Internet Explorer.\nVous pouvez toujours copier puis coller le lien.';
 $lang['js']['linkwiz']         = 'Assistant Lien';
 $lang['js']['linkto']          = 'Lien vers :';
-$lang['js']['del_confirm']     = 'Effacer cette entrée ?';
-$lang['js']['restore_confirm'] = 'Voulez vous vraiment restaurer cette version ?';
-$lang['js']['media_diff']      = 'Voir les différences:';
+$lang['js']['del_confirm']     = 'Voulez-vous vraiment effacer ce(s) élément(s) ?';
+$lang['js']['restore_confirm'] = 'Voulez-vous vraiment restaurer cette version ?';
+$lang['js']['media_diff']      = 'Voir les différences :';
 $lang['js']['media_diff_both'] = 'Côte à côte';
 $lang['js']['media_diff_opacity'] = 'Calque';
 $lang['js']['media_diff_portions'] = 'Curseur';
 $lang['js']['media_select']    = 'Sélection de fichiers…';
-$lang['js']['media_upload_btn'] = 'Télécharger';
+$lang['js']['media_upload_btn'] = 'Envoyer';
 $lang['js']['media_done_btn']  = 'Terminé';
-$lang['js']['media_drop']      = 'Déposez des fichiers ici pour les télécharger';
+$lang['js']['media_drop']      = 'Déposez des fichiers ici pour les envoyer';
 $lang['js']['media_cancel']    = 'supprimer';
 $lang['js']['media_overwrt']   = 'Écraser les fichiers existants';
 $lang['rssfailed']             = 'Une erreur s\'est produite en récupérant ce flux : ';
 $lang['nothingfound']          = 'Pas de réponse.';
-$lang['mediaselect']           = 'Sélection de fichier';
+$lang['mediaselect']           = 'Sélection de fichiers';
 $lang['fileupload']            = 'Envoi de fichier';
-$lang['uploadsucc']            = 'Téléversement réussi';
-$lang['uploadfail']            = 'Le téléversement n\'a pas réussi. Les permissions sont-elles correctes ?';
-$lang['uploadwrong']           = 'Téléversement refusé. Cette extension de fichier est interdite !';
-$lang['uploadexist']           = 'Le fichier existe. Téléversement avorté.';
-$lang['uploadbadcontent']      = 'Le contenu envoyé ne correspond pas à l\'extension du fichier %s.';
-$lang['uploadspam']            = 'Le téléversement a été bloqué par la liste noire antispam.';
-$lang['uploadxss']             = 'Le téléversement a été bloqué car son contenu est peut-être malveillant.';
-$lang['uploadsize']            = 'Le fichier téléversé était trop gros. (max. %s)';
+$lang['uploadsucc']            = 'Envoi réussi';
+$lang['uploadfail']            = 'L\'envoi a échoué. Les autorisations sont-elles correctes ?';
+$lang['uploadwrong']           = 'Envoi refusé. Cette extension de fichier est interdite !';
+$lang['uploadexist']           = 'Le fichier existe déjà. L\'envoi a été annulé.';
+$lang['uploadbadcontent']      = 'Le contenu envoyé ne correspond pas à l\'extension du fichier (%s).';
+$lang['uploadspam']            = 'L\'envoi a été bloqué par la liste noire de l\'anti-spam.';
+$lang['uploadxss']             = 'L\'envoi a été bloqué car son contenu est peut-être malveillant.';
+$lang['uploadsize']            = 'Le fichier envoyé était trop gros. (max. : %s)';
 $lang['deletesucc']            = 'Le fichier « %s » a été effacé.';
-$lang['deletefail']            = 'Le fichier « %s » n\'a pu être effacé, vérifier les permissions.';
-$lang['mediainuse']            = 'Le fichier « %s » n\'a pas été effacé, il est en cours d\'utilisation.';
+$lang['deletefail']            = 'Le fichier « %s » n\'a pas pu être effacé. Vérifiez les autorisations.';
+$lang['mediainuse']            = 'Le fichier « %s » n\'a pas été effacé : il est en toujours utilisé.';
 $lang['namespaces']            = 'Catégories';
 $lang['mediafiles']            = 'Fichiers disponibles dans';
 $lang['accessdenied']          = 'Vous n\'êtes pas autorisé à voir cette page.';
 $lang['mediausage']            = 'Utilisez la syntaxe suivante pour faire référence à ce fichier :';
 $lang['mediaview']             = 'Afficher le fichier original';
 $lang['mediaroot']             = 'racine';
-$lang['mediaupload']           = 'Téléverser un fichier dans la catégorie actuelle. Pour créer des sous-catégories, préfixez le nom du fichier par le nom de la sous-catégorie séparée par un double-point.';
-$lang['mediaextchange']        = 'Extension du fichier changée de .%s en .%s !';
+$lang['mediaupload']           = 'Envoyez un fichier dans la catégorie actuelle. Pour créer des sous-catégories, préfixez en le nom du fichier séparées par un double-point, après avoir choisis le(s) fichier(s). Le(s) fichier(s) peuvent également être envoyé(s) par glisser-déposer (drag & drop)';
+$lang['mediaextchange']        = 'Extension du fichier modifiée de .%s en .%s !';
 $lang['reference']             = 'Références pour';
-$lang['ref_inuse']             = 'Le fichier ne peut être effacé car il est utilisé par les pages suivantes :';
-$lang['ref_hidden']            = 'Des références existent dans des pages que vous n\'avez pas la permission de lire';
+$lang['ref_inuse']             = 'Le fichier ne peut être effacé car il est toujours utilisé par les pages suivantes :';
+$lang['ref_hidden']            = 'Des références sont présentes dans des pages que vous ne pouvez pas voir (autorisations insuffisantes)';
 $lang['hits']                  = 'Occurrences trouvées';
 $lang['quickhits']             = 'Pages trouvées ';
 $lang['toc']                   = 'Table des matières';
@@ -187,7 +189,7 @@ $lang['current']               = 'Version actuelle';
 $lang['yours']                 = 'Votre version';
 $lang['diff']                  = 'Différences avec la version actuelle';
 $lang['diff2']                 = 'Différences entre les versions sélectionnées';
-$lang['difflink']              = 'Lien vers cette vue';
+$lang['difflink']              = 'Lien vers cette vue comparative';
 $lang['diff_type']             = 'Voir les différences :';
 $lang['diff_inline']           = 'Sur une seule ligne';
 $lang['diff_side']             = 'Côte à côte';
@@ -196,18 +198,19 @@ $lang['breadcrumb']            = 'Piste';
 $lang['youarehere']            = 'Vous êtes ici';
 $lang['lastmod']               = 'Dernière modification';
 $lang['by']                    = 'par';
-$lang['deleted']               = 'effacée';
+$lang['deleted']               = 'supprimée';
 $lang['created']               = 'créée';
-$lang['restored']              = 'ancienne révision restaurée';
+$lang['restored']              = 'ancienne révision (%s) restaurée';
 $lang['external_edit']         = 'modification externe';
 $lang['summary']               = 'Résumé';
-$lang['noflash']               = 'Le greffon <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash</a> est nécessaire pour afficher ce contenu.';
+$lang['noflash']               = 'L\'<a href="http://www.adobe.com/products/flashplayer/">extension Adobe Flash</a> est nécessaire pour afficher ce contenu.';
 $lang['download']              = 'Télécharger un extrait';
 $lang['tools']                 = 'Outils';
-$lang['user_tools']            = 'Outils d\'utilisateurs';
-$lang['site_tools']            = 'Outils du Site';
-$lang['page_tools']            = 'Outils de la Page';
+$lang['user_tools']            = 'Outils pour utilisateurs';
+$lang['site_tools']            = 'Outils du site';
+$lang['page_tools']            = 'Outils de la page';
 $lang['skip_to_content']       = 'Aller au contenu';
+$lang['sidebar']               = 'Panneau latéral';
 $lang['mail_newpage']          = 'page ajoutée :';
 $lang['mail_changed']          = 'page modifiée :';
 $lang['mail_subscribe_list']   = 'pages modifiées dans la catégorie :';
@@ -215,13 +218,13 @@ $lang['mail_new_user']         = 'nouvel utilisateur :';
 $lang['mail_upload']           = 'fichier envoyé :';
 $lang['changes_type']          = 'Voir les changements';
 $lang['pages_changes']         = 'Pages';
-$lang['media_changes']         = 'Fichier multimédias';
+$lang['media_changes']         = 'Fichiers multimédias';
 $lang['both_changes']          = 'Pages et fichiers multimédias';
-$lang['qb_bold']               = 'Emphase forte (gras)';
-$lang['qb_italic']             = 'Emphase (italique)';
-$lang['qb_underl']             = 'Souligné';
+$lang['qb_bold']               = 'Gras';
+$lang['qb_italic']             = 'Italique';
+$lang['qb_underl']             = 'Soulignage';
 $lang['qb_code']               = 'Code « machine à écrire »';
-$lang['qb_strike']             = 'Texte barré';
+$lang['qb_strike']             = 'Barré';
 $lang['qb_h1']                 = 'Titre de niveau 1';
 $lang['qb_h2']                 = 'Titre de niveau 2';
 $lang['qb_h3']                 = 'Titre de niveau 3';
@@ -237,14 +240,14 @@ $lang['qb_extlink']            = 'Lien externe';
 $lang['qb_hr']                 = 'Ligne horizontale';
 $lang['qb_ol']                 = 'Liste numérotée';
 $lang['qb_ul']                 = 'Liste à puce';
-$lang['qb_media']              = 'Ajouter des images ou d\'autres fichiers';
+$lang['qb_media']              = 'Ajouter des images ou autres fichiers';
 $lang['qb_sig']                = 'Insérer une signature';
 $lang['qb_smileys']            = 'Émoticones';
 $lang['qb_chars']              = 'Caractères spéciaux';
 $lang['upperns']               = 'Aller à la catégorie parente';
 $lang['admin_register']        = 'Ajouter un nouvel utilisateur';
 $lang['metaedit']              = 'Modifier les métadonnées';
-$lang['metasaveerr']           = 'Erreur lors de l\'écriture des métadonnées';
+$lang['metasaveerr']           = 'Erreur lors de l\'enregistrement des métadonnées';
 $lang['metasaveok']            = 'Métadonnées enregistrées';
 $lang['img_backto']            = 'Retour à';
 $lang['img_title']             = 'Titre';
@@ -252,7 +255,7 @@ $lang['img_caption']           = 'Légende';
 $lang['img_date']              = 'Date';
 $lang['img_fname']             = 'Nom de fichier';
 $lang['img_fsize']             = 'Taille';
-$lang['img_artist']            = 'Auteur';
+$lang['img_artist']            = 'Photographe';
 $lang['img_copyr']             = 'Copyright';
 $lang['img_format']            = 'Format';
 $lang['img_camera']            = 'Appareil photo';
@@ -261,47 +264,50 @@ $lang['img_width']             = 'Largeur';
 $lang['img_height']            = 'Hauteur';
 $lang['img_manager']           = 'Voir dans le gestionnaire de médias';
 $lang['subscr_subscribe_success'] = '%s a été ajouté à la liste de souscription de %s';
-$lang['subscr_subscribe_error'] = 'Erreur en ajoutant %s à la liste de souscription de %s';
+$lang['subscr_subscribe_error'] = 'Erreur à l\'ajout de %s à la liste de souscription de %s';
 $lang['subscr_subscribe_noaddress'] = 'Il n\'y a pas d\'adresse associée à votre identifiant, vous ne pouvez pas être ajouté à la liste de souscription';
-$lang['subscr_unsubscribe_success'] = '%s a été retiré de la liste de souscription de %s';
-$lang['subscr_unsubscribe_error'] = 'Erreur en retirant %s de la liste de souscription de %s';
+$lang['subscr_unsubscribe_success'] = '%s a été supprimé de la liste de souscription de %s';
+$lang['subscr_unsubscribe_error'] = 'Erreur au retrait de %s de la liste de souscription de %s';
 $lang['subscr_already_subscribed'] = '%s est déjà souscrit à %s';
 $lang['subscr_not_subscribed'] = '%s n\'est pas souscrit à %s';
-$lang['subscr_m_not_subscribed'] = 'Vous n\'avez pas souscrit pour l\'instant à la page actuelle ou la catégorie';
+$lang['subscr_m_not_subscribed'] = 'Vous n\'avez pas souscrit pour l\'instant à la page actuelle ou à la catégorie';
 $lang['subscr_m_new_header']   = 'Ajouter une souscription';
 $lang['subscr_m_current_header'] = 'Souscriptions actives';
 $lang['subscr_m_unsubscribe']  = 'Annuler la souscription';
 $lang['subscr_m_subscribe']    = 'Souscrire';
 $lang['subscr_m_receive']      = 'Recevoir';
-$lang['subscr_style_every']    = 'Envoyer un courriel à chaque modification';
+$lang['subscr_style_every']    = 'Recevoir un courriel à chaque modification';
 $lang['subscr_style_digest']   = 'Courriel, tous les %.2f jours, résumant les modifications de chaque page';
 $lang['subscr_style_list']     = 'Liste des pages modifiées depuis le dernier courriel (tous les %.2f jours)';
-$lang['authmodfailed']         = 'Mauvais paramétrage de l\'authentification. Merci d\'informer l\'administrateur du Wiki.';
-$lang['authtempfail']          = 'L\'authentification est temporairement indisponible. Si cela perdure, merci d\'informer l\'administrateur du Wiki.';
+$lang['authmodfailed']         = 'Mauvais paramétrage de l\'authentification. Merci d\'en informer l\'administrateur du wiki.';
+$lang['authtempfail']          = 'L\'authentification est temporairement indisponible. Si cela perdure, merci d\'en informer l\'administrateur du wiki.';
 $lang['authpwdexpire']         = 'Votre mot de passe expirera dans %d jours, vous devriez le changer bientôt.';
 $lang['i_chooselang']          = 'Choisissez votre langue';
-$lang['i_installer']           = 'Installeur DokuWiki';
+$lang['i_installer']           = 'Installateur DokuWiki';
 $lang['i_wikiname']            = 'Nom du wiki';
-$lang['i_enableacl']           = 'Activer les ACL (recommandé)';
+$lang['i_enableacl']           = 'Activer le contrôle d\'accès (recommandé)';
 $lang['i_superuser']           = 'Super-utilisateur';
-$lang['i_problems']            = 'L\'installeur a détecté les problèmes indiqués ci-dessous. Vous ne pouvez poursuivre tant qu\'ils n\'auront pas été corrigés.';
-$lang['i_modified']            = 'Pour des raisons de sécurité ce script ne fonctionne qu\'avec une installation neuve et non modifiée de DokuWiki. Vous devriez ré-extraire les fichiers depuis le paquet téléchargé ou consulter les <a href="http://dokuwiki.org/install">instructions d\'installation de DokuWiki</a>';
-$lang['i_funcna']              = 'La fonction PHP <code>%s</code> n\'est pas disponible. Peut-être que votre hébergeur l\'a désactivée ?';
+$lang['i_problems']            = 'L\'installateur a détecté les problèmes indiqués ci-dessous. Vous ne pouvez pas poursuivre l\'installation tant qu\'ils n\'auront pas été corrigés.';
+$lang['i_modified']            = 'Pour des raisons de sécurité, ce script ne fonctionne qu\'avec une installation neuve et non modifiée de DokuWiki. Vous devriez ré-extraire les fichiers depuis le paquet téléchargé ou consulter les <a href="http://dokuwiki.org/install">instructions d\'installation de DokuWiki</a>';
+$lang['i_funcna']              = 'La fonction PHP <code>%s</code> n\'est pas disponible. Peut-être que votre hébergeur web l\'a désactivée ?';
 $lang['i_phpver']              = 'Votre version de PHP (%s) est antérieure à la version requise (%s). Vous devez mettre à jour votre installation de PHP.';
-$lang['i_permfail']            = '<code>%s</code> n\'est pas accessible en écriture pour DokuWiki. Vous devez corriger les permissions de ce répertoire !';
+$lang['i_permfail']            = '<code>%s</code> n\'est pas accessible en écriture pour DokuWiki. Vous devez corriger les autorisations de ce répertoire !';
 $lang['i_confexists']          = '<code>%s</code> existe déjà';
-$lang['i_writeerr']            = 'Impossible de créer <code>%s</code>. Vous devez vérifier les permissions des répertoires/fichiers et créer le fichier manuellement.';
+$lang['i_writeerr']            = 'Impossible de créer <code>%s</code>. Vous devez vérifier les autorisations des répertoires/fichiers et créer le fichier manuellement.';
 $lang['i_badhash']             = 'dokuwiki.php non reconnu ou modifié (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - valeur interdite ou vide';
-$lang['i_success']             = 'L\'installation s\'est terminée avec succès. Vous pouvez maintenant supprimer le fichier « install.php ». Continuer avec <a href="doku.php">votre nouveau DokuWiki</a>.';
+$lang['i_success']             = 'L\'installation s\'est terminée avec succès. Vous pouvez maintenant supprimer le fichier « install.php ». Continuer avec <a href="doku.php?id=wiki:welcome">votre nouveau DokuWiki</a>.';
 $lang['i_failure']             = 'Des erreurs sont survenues lors de l\'écriture des fichiers de configuration. Il vous faudra les corriger manuellement avant de pouvoir utiliser <a href="doku.php">votre nouveau DokuWiki</a>.';
-$lang['i_policy']              = 'Politique d\'ACL initiale';
+$lang['i_policy']              = 'Politique de contrôle d\'accès initiale';
 $lang['i_pol0']                = 'Wiki ouvert (lecture, écriture, envoi de fichiers pour tout le monde)';
 $lang['i_pol1']                = 'Wiki public (lecture pour tout le monde, écriture et envoi de fichiers pour les utilisateurs enregistrés)';
 $lang['i_pol2']                = 'Wiki fermé (lecture, écriture, envoi de fichiers pour les utilisateurs enregistrés uniquement)';
 $lang['i_retry']               = 'Réessayer';
-$lang['i_license']             = 'Veuillez choisir la licence sous laquelle placer votre contenu :';
-$lang['recent_global']         = 'Vous êtes actuellement en train de regarder les modifications au sein de la catégorie <strong>%s</strong>. Vous pouvez aussi <a href="%s">voir les récentes modifications sur tout le wiki</a>.';
+$lang['i_license']             = 'Veuillez choisir la licence sous laquelle vous souhaitez placer votre contenu :';
+$lang['i_license_none']        = 'Ne pas afficher d\'information de licence.';
+$lang['i_pop_field']           = 'Merci de nous aider à améliorer l\'expérience DokuWiki:';
+$lang['i_pop_label']           = 'Une fois par mois, envoyer des données d\'utilisation anonymes aux développeurs DokuWiki';
+$lang['recent_global']         = 'Vous êtes actuellement en train de regarder les modifications au sein de la catégorie <strong>%s</strong>. Vous pouvez également <a href="%s">afficher les derniers changements sur l\'ensemble du wiki</a>.';
 $lang['years']                 = 'il y a %d ans';
 $lang['months']                = 'il y a %d mois';
 $lang['weeks']                 = 'il y a %d semaines';
@@ -309,27 +315,27 @@ $lang['days']                  = 'il y a %d jours';
 $lang['hours']                 = 'il y a %d heures';
 $lang['minutes']               = 'il y a %d minutes';
 $lang['seconds']               = 'il y a %d secondes';
-$lang['wordblock']             = 'Vos modifications n\'ont pas été sauvegardées parce qu\'elles contiennent des textes non autorisé (spam).';
-$lang['media_uploadtab']       = 'Télécharger';
+$lang['wordblock']             = 'Vos modifications n\'ont pas été enregistrées car elles contiennent du texte non autorisé (spam).';
+$lang['media_uploadtab']       = 'Envoyer';
 $lang['media_searchtab']       = 'Rechercher';
 $lang['media_file']            = 'Fichier';
 $lang['media_viewtab']         = 'Voir';
 $lang['media_edittab']         = 'Éditer';
 $lang['media_historytab']      = 'Historique';
-$lang['media_list_thumbs']     = 'Aperçus';
+$lang['media_list_thumbs']     = 'Miniatures';
 $lang['media_list_rows']       = 'Lignes';
-$lang['media_sort_name']       = 'Tri par nom';
-$lang['media_sort_date']       = 'Tri par date';
-$lang['media_namespaces']      = 'Choisissez un espace de nom';
-$lang['media_files']           = 'Fichiers de %s';
-$lang['media_upload']          = 'Télécharger dans %s.';
-$lang['media_search']          = 'Chercher dans %s.';
+$lang['media_sort_name']       = 'Nom';
+$lang['media_sort_date']       = 'Date';
+$lang['media_namespaces']      = 'Choisissez une catégorie';
+$lang['media_files']           = 'Fichiers dans %s';
+$lang['media_upload']          = 'Envoyer vers %s.';
+$lang['media_search']          = 'Rechercher dans %s.';
 $lang['media_view']            = '%s';
 $lang['media_viewold']         = '%s dans %s';
 $lang['media_edit']            = 'Éditer %s';
 $lang['media_history']         = 'Historique de %s';
 $lang['media_meta_edited']     = 'métadonnées éditées';
-$lang['media_perm_read']       = 'Désolé, vous n\'avez pas les droits pour lire les fichiers.';
-$lang['media_perm_upload']     = 'Désolé, vous n\'avez pas les droits pour télécharger des fichiers.';
-$lang['media_update']          = 'Télécharger une nouvelle version';
+$lang['media_perm_read']       = 'Désolé, vous n\'avez pas l\'autorisation de voir les fichiers.';
+$lang['media_perm_upload']     = 'Désolé, vous n\'avez pas l\'autorisation d\'envoyer des fichiers.';
+$lang['media_update']          = 'Envoyer une nouvelle version';
 $lang['media_restore']         = 'Restaurer cette version';
