@@ -169,7 +169,7 @@ $lang['lastmod']               = 'Utolsó módosítás';
 $lang['by']                    = 'szerkesztette:';
 $lang['deleted']               = 'eltávolítva';
 $lang['created']               = 'létrehozva';
-$lang['restored']              = 'az előző változat helyreállítva';
+$lang['restored']              = 'az előző változat helyreállítva (%s)';
 $lang['external_edit']         = 'külső szerkesztés';
 $lang['summary']               = 'A változások összefoglalása';
 $lang['noflash']               = 'Ennek a tartalomnak a megtekintéséhez <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> szükséges.';
@@ -252,8 +252,8 @@ $lang['i_confexists']          = '<code>%s</code> már létezik.';
 $lang['i_writeerr']            = 'Nem tudom ezt létrehozni: <code>%s</code>. Ellenőrizd a könyvtár/fájl jogosultságokat, és hozd létre az állományt kézzel.';
 $lang['i_badhash']             = 'A dokuwiki.php nem felismerhető vagy módosított (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - nem helyes vagy üres érték';
-$lang['i_success']             = 'A beállítás sikeresen befejeződött. Most már letörölhető az install.php fájl. Látogasd meg az <a href="doku.php">új DokuWikidet</a>!';
-$lang['i_failure']             = 'Hiba lépett fel a konfigurációs állományok írásakor. Ki kell javítanod kézzel, mielőtt használni kezded az <a href="doku.php">új DokuWikidet</a>.';
+$lang['i_success']             = 'A beállítás sikeresen befejeződött. Most már letörölhető az install.php fájl. Látogasd meg az <a href="doku.php?id=wiki:welcome">új DokuWikidet</a>!';
+$lang['i_failure']             = 'Hiba lépett fel a konfigurációs állományok írásakor. Ki kell javítanod kézzel, mielőtt használni kezded az <a href="doku.php?id=wiki:welcome">új DokuWikidet</a>.';
 $lang['i_policy']              = 'Kezdeti hozzáférési politika';
 $lang['i_pol0']                = 'Nyitott Wiki (mindenki olvashatja, írhatja, és fájlokat tölthet fel)';
 $lang['i_pol1']                = 'Publikus Wiki (mindenki olvashatja, de csak regisztrált felhasználók írhatják, és tölthetnek fel fájlokat)';
