@@ -84,7 +84,7 @@ $lang['txt_overwrt']           = 'File yang telah ada akan ditindih';
 $lang['lockedby']              = 'Sedang dikunci oleh';
 $lang['lockexpire']            = 'Penguncian artikel sampai dengan';
 $lang['js']['willexpire']            = 'Halaman yang sedang Anda kunci akan berakhir dalam waktu kurang lebih satu menit.\nUntuk menghindari konflik, gunakan tombol Preview untuk me-reset timer pengunci.';
-$lang['js']['notsavedyet']     = "Perubahan yang belum disimpan akan hilang.\nYakin akan dilanjutkan?";
+$lang['js']['notsavedyet']     = 'Perubahan yang belum disimpan akan hilang.\nYakin akan dilanjutkan?';
 $lang['rssfailed']             = 'Error terjadi saat mengambil feed: ';
 $lang['nothingfound']          = 'Tidak menemukan samasekali.';
 $lang['mediaselect']           = 'Pilihan Mediafile';
@@ -125,7 +125,7 @@ $lang['lastmod']               = 'Terakhir diubah';
 $lang['by']                    = 'oleh';
 $lang['deleted']               = 'terhapus';
 $lang['created']               = 'dibuat';
-$lang['restored']              = 'revisi lama ditampilkan kembali';
+$lang['restored']              = 'revisi lama ditampilkan kembali (%s)';
 $lang['external_edit']         = 'Perubahan eksternal';
 $lang['summary']               = 'Edit summary';
 $lang['mail_newpage']          = 'Halaman ditambahkan:';
@@ -188,8 +188,8 @@ $lang['i_confexists']          = '<code>%s</code> sudah ada';
 $lang['i_writeerr']            = 'Tidak dapat membuat <code>%s</code>. Anda harus memeriksa konfigurasi hak akses direktori/berkas dan membuatnya secara manual.';
 $lang['i_badhash']             = 'dokuwiki.php tidak dikenal atau sudah diubah (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - tidak valid atau belum diisi';
-$lang['i_success']             = 'Konfigurasi telah berhasil. Anda boleh menghapus berkas install.php sekarang. Lanjutkan ke <a href="doku.php">DokuWiki baru Anda</a>.';
-$lang['i_failure']             = 'Terdapat beberapa kesalahan dalam menulis berkas konfigurasi. Anda harus memperbaikinnya sendiri sebelum dapat menggunakan <a href="doku.php">DokuWiki baru Anda</a>.';
+$lang['i_success']             = 'Konfigurasi telah berhasil. Anda boleh menghapus berkas install.php sekarang. Lanjutkan ke <a href="doku.php?id=wiki:welcome">DokuWiki baru Anda</a>.';
+$lang['i_failure']             = 'Terdapat beberapa kesalahan dalam menulis berkas konfigurasi. Anda harus memperbaikinnya sendiri sebelum dapat menggunakan <a href="doku.php?id=wiki:welcome">DokuWiki baru Anda</a>.';
 $lang['i_policy']              = 'Policy ACL awal';
 $lang['i_pol0']                = 'Wiki Terbuka (baca, tulis, upload untuk semua orang)';
 $lang['i_pol1']                = 'Wiki Publik (baca untuk semua orang, tulis dan upload untuk pengguna terdaftar)';
