@@ -187,7 +187,7 @@ $lang['lastmod']               = 'Ultima modifica';
 $lang['by']                    = 'da';
 $lang['deleted']               = 'eliminata';
 $lang['created']               = 'creata';
-$lang['restored']              = 'versione precedente ripristinata';
+$lang['restored']              = 'versione precedente ripristinata (%s)';
 $lang['external_edit']         = 'modifica esterna';
 $lang['summary']               = 'Oggetto della modifica';
 $lang['noflash']               = 'E\' necessario <a href="http://www.adobe.com/products/flashplayer/">il plugin Adobe Flash</a> per visualizzare questo contenuto.';
@@ -205,6 +205,7 @@ $lang['mail_new_user']         = 'nuovo utente:';
 $lang['mail_upload']           = 'file caricato:';
 $lang['changes_type']          = 'Guarda cambiamenti di';
 $lang['pages_changes']         = 'Pagine';
+$lang['media_changes']         = 'File multimediali';
 $lang['both_changes']          = 'Sia pagine che media files';
 $lang['qb_bold']               = 'Grassetto';
 $lang['qb_italic']             = 'Corsivo';
@@ -263,8 +264,8 @@ $lang['subscr_m_unsubscribe']  = 'Rimuovi sottoscrizione';
 $lang['subscr_m_subscribe']    = 'Sottoscrivi';
 $lang['subscr_m_receive']      = 'Ricevi';
 $lang['subscr_style_every']    = 'email per ogni modifica';
-$lang['subscr_style_digest']   = 'email riassuntiva delle modifiche di ogni pagina';
-$lang['subscr_style_list']     = 'elenco delle pagine modificate dall\'ultima email';
+$lang['subscr_style_digest']   = 'email di riassunto dei cambiamenti per ogni pagina (ogni %.2f giorni)';
+$lang['subscr_style_list']     = 'lista delle pagine cambiate dall\'ultima email (ogni %.2f giorni)';
 $lang['authmodfailed']         = 'La configurazione dell\'autenticazione non è corretta. Informa l\'amministratore di questo wiki.';
 $lang['authtempfail']          = 'L\'autenticazione è temporaneamente non disponibile. Se questa situazione persiste, informa l\'amministratore di questo wiki.';
 $lang['authpwdexpire']         = 'La tua password scadrà in %d giorni, dovresti cambiarla quanto prima.';
@@ -284,14 +285,17 @@ $lang['i_confexists']          = '<code>%s</code> esiste già';
 $lang['i_writeerr']            = 'Impossibile creare <code>%s</code>. E\' necessario verificare i permessi della directory o del file oppure creare il file manualmente.';
 $lang['i_badhash']             = 'dokuwiki.php (hash=<code>%s</code>) non riconosciuto o modificato';
 $lang['i_badval']              = '<code>%s</code> - valore vuoto o non valido';
-$lang['i_success']             = 'La configurazione è stata completata correttamente. Ora è possibile eliminare il file install.php. Poi, visita <a href="doku.php">il tuo nuovo DokuWiki</a>.';
-$lang['i_failure']             = 'Si sono verificati errori durante la scrittura dei file di configurazione. Potrebbe essere necessario correggerli manualmente prima di poter utilizzare <a href="doku.php">il tuo nuovo DokuWiki</a>.';
+$lang['i_success']             = 'La configurazione è stata completata correttamente. Ora è possibile eliminare il file install.php. Poi, visita <a href="doku.php?id=wiki:welcome">il tuo nuovo DokuWiki</a>.';
+$lang['i_failure']             = 'Si sono verificati errori durante la scrittura dei file di configurazione. Potrebbe essere necessario correggerli manualmente prima di poter utilizzare <a href="doku.php?id=wiki:welcome">il tuo nuovo DokuWiki</a>.';
 $lang['i_policy']              = 'Regole di accesso iniziali';
 $lang['i_pol0']                = 'Wiki Aperto (lettura, scrittura, caricamento file per tutti)';
 $lang['i_pol1']                = 'Wiki Pubblico (lettura per tutti, scrittura e caricamento file per gli utenti registrati)';
 $lang['i_pol2']                = 'Wiki Chiuso (lettura, scrittura, caricamento file solamente per gli utenti registrati)';
 $lang['i_retry']               = 'Riprova';
 $lang['i_license']             = 'Per favore scegli la licenza sotto cui vuoi rilasciare il contenuto:';
+$lang['i_license_none']        = 'Non mostrare informazioni sulla licenza';
+$lang['i_pop_field']           = 'Per favore, aiutaci ad incrementare la conoscenza di DokuWiki:';
+$lang['i_pop_label']           = 'Mensilmente invia una statistica d\'uso anonima di DokuWiki agli sviluppatori';
 $lang['recent_global']         = 'Stai attualmente vedendo le modifiche effettuate nell\'area <b>%s</b>. Puoi anche <a href="%s">vedere le modifiche recenti dell\'intero wiki</a>.';
 $lang['years']                 = '%d anni fa';
 $lang['months']                = '%d mesi fa';
@@ -316,8 +320,10 @@ $lang['media_files']           = 'File in %s';
 $lang['media_upload']          = 'Upload al %s';
 $lang['media_search']          = 'Cerca in %s';
 $lang['media_view']            = '%s';
+$lang['media_viewold']         = '%s a %s';
 $lang['media_edit']            = 'Modifica %s';
 $lang['media_history']         = 'Storia di %s';
+$lang['media_meta_edited']     = 'metadata modificati';
 $lang['media_perm_read']       = 'Spiacente, non hai abbastanza privilegi per leggere i files.';
 $lang['media_perm_upload']     = 'Spiacente, non hai abbastanza privilegi per caricare files.';
 $lang['media_update']          = 'Carica nuova versione';
