@@ -83,7 +83,7 @@ $lang['txt_overwrt']           = 'Bestehend Datei iwwerschreiwen';
 $lang['lockedby']              = 'Am Moment gespaart vun';
 $lang['lockexpire']            = 'D\'Spär leeft of ëm';
 $lang['js']['willexpire']            = 'Deng Spär fir d\'Säit ze änneren leeft an enger Minutt of.\nFir Konflikter ze verhënneren, dréck op Kucken ouni ofzespäicheren.';
-$lang['js']['notsavedyet']     = "Net gespäicher Ännerunge gi verluer.\nWierklech weiderfueren?";
+$lang['js']['notsavedyet']     = 'Net gespäicher Ännerunge gi verluer.\nWierklech weiderfueren?';
 $lang['rssfailed']             = 'Et ass e Feeler virkomm beim erofluede vun dësem Feed: ';
 $lang['nothingfound']          = 'Näischt fond.';
 $lang['mediaselect']           = 'Mediadateien';
@@ -124,7 +124,7 @@ $lang['lastmod']               = 'Fir d\'lescht g\'ännert';
 $lang['by']                    = 'vun';
 $lang['deleted']               = 'geläscht';
 $lang['created']               = 'erstallt';
-$lang['restored']              = 'al Versioun zeréckgeholl';
+$lang['restored']              = 'al Versioun zeréckgeholl (%s)';
 $lang['external_edit']         = 'extern Ännerung';
 $lang['summary']               = 'Resumé vun den Ännerungen';
 $lang['noflash']               = 'Den <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> get gebraucht fir dësen Inhalt unzeweisen.';
