@@ -91,7 +91,7 @@ $lang['txt_overwrt']           = 'Пребриши ја веќе постоеч
 $lang['lockedby']              = 'Моментално заклучена од';
 $lang['lockexpire']            = 'Клучот истекува на';
 $lang['js']['willexpire']            = 'Вашиот клуч за уредување на оваа страница ќе истече за една минута.\nЗа да избегнете конфликти и да го ресетирате бројачот за време, искористете го копчето за преглед.';
-$lang['js']['notsavedyet']     = "Незачуваните промени ќе бидат изгубени.\nСакате да продолжите?";
+$lang['js']['notsavedyet']     = 'Незачуваните промени ќе бидат изгубени.\nСакате да продолжите?';
 $lang['rssfailed']             = 'Се појави грешка при повлекувањето на овој канал:';
 $lang['nothingfound']          = 'Ништо не е пронајдено.';
 $lang['mediaselect']           = 'Медиа датотеки';
@@ -136,7 +136,7 @@ $lang['lastmod']               = 'Последно изменета';
 $lang['by']                    = 'од';
 $lang['deleted']               = 'отстранета';
 $lang['created']               = 'креирана';
-$lang['restored']              = 'обновена е стара ревизија';
+$lang['restored']              = 'обновена е стара ревизија (%s)';
 $lang['external_edit']         = 'надворешно уредување';
 $lang['summary']               = 'Уреди го изводот';
 $lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash приклучокот</a> е потребен за да се прикаже оваа содржина.';
@@ -196,8 +196,6 @@ $lang['subscr_m_unsubscribe']  = 'Отплатување';
 $lang['subscr_m_subscribe']    = 'Претплата';
 $lang['subscr_m_receive']      = 'Прими';
 $lang['subscr_style_every']    = 'е-пошта за секоја промена';
-$lang['subscr_style_digest']   = 'е-пошта со преглед од промените за секоја страница';
-$lang['subscr_style_list']     = 'листа на променети страници од последната е-пошта';
 $lang['authmodfailed']         = 'Лоша конфигурација за автентикација на корисник. Ве молам информирајте го вики администратор.';
 $lang['authtempfail']          = 'Автентикација на корисник е привремено недостапна. Ако оваа ситуација истрајува, ве молам известете го вики администратор.';
 $lang['i_chooselang']          = 'Избере јазик';
@@ -214,8 +212,8 @@ $lang['i_confexists']          = '<code>%s</code> веќе постои';
 $lang['i_writeerr']            = 'Не може да се креира <code>%s</code>. Треба да ги проверите пермисиите на директориумот/датотеката и рачно да ја креирате датотеката.';
 $lang['i_badhash']             = 'непозната или изменете dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - нелегална или празна вредност';
-$lang['i_success']             = 'Конфигурацијата успешно заврши. Сега можете да ја избришете датотеката install.php. Продолжете до <a href="doku.php">вашето ново DokuWiki</a>.';
-$lang['i_failure']             = 'Се појавија некои грешки при запишувањето на конфигурациските датотеки. Можеби треба да ги поравите рачно пред да можете да го користите <a href="doku.php">вашето ново DokuWiki</a>.';
+$lang['i_success']             = 'Конфигурацијата успешно заврши. Сега можете да ја избришете датотеката install.php. Продолжете до <a href="doku.php?id=wiki:welcome">вашето ново DokuWiki</a>.';
+$lang['i_failure']             = 'Се појавија некои грешки при запишувањето на конфигурациските датотеки. Можеби треба да ги поравите рачно пред да можете да го користите <a href="doku.php?id=wiki:welcome">вашето ново DokuWiki</a>.';
 $lang['i_policy']              = 'Почетна ACL политика';
 $lang['i_pol0']                = 'Отвори вики (читај, запиши, качи за сите)';
 $lang['i_pol1']                = 'Јавно вики (читај за сите, запиши и качи за регистрирани корисници)';
