@@ -180,7 +180,6 @@ $lang['lastmod']               = 'सर्वात शेवटचा बद
 $lang['by']                    = 'द्वारा';
 $lang['deleted']               = 'काढून टाकले';
 $lang['created']               = 'निर्माण केले';
-$lang['restored']              = 'जुनी आवृत्ति पुनर्स्थापित केली';
 $lang['external_edit']         = 'बाहेरून संपादित';
 $lang['summary']               = 'सारांश बदला';
 $lang['noflash']               = 'ही माहिती दाखवण्यासाठी <a href="http://www.adobe.com/products/flashplayer/">अडोब फ्लॅश प्लेअर</a> ची गरज आहे.';
@@ -258,8 +257,8 @@ $lang['i_confexists']          = '<code>%s</code> आधीच अस्ति
 $lang['i_writeerr']            = '<code>%s</code> निर्माण करू शकलो नाही. तुम्हाला डिरेक्टरी / फाइल च्या परवानग्या तपासून स्वतःच ही फाइल बनवावी लागेल.';
 $lang['i_badhash']             = 'अनाकलनीय किंवा बदललेले dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = 'code>%s</code> - अवैध किंवा रिकामा मजकूर.';
-$lang['i_success']             = 'व्यवस्था लावण्याचे काम यशस्वीरीत्या पार पडले. आता तुम्ही install.php डिलीट करू शकता. <a href="doku.php">तुमच्या नविन डॉक्युविकि </a> वर जा.';
-$lang['i_failure']             = 'कॉन्फिगुरेशनच्या फाइल सुरक्षित करताना काही अडचणी आल्या आहेत. <a href="doku.php">तुमची नवीन डॉक्युविकि </a> वापरण्याआधी तुम्हाला ह्या फाइल स्वतः ठीक कराव्या लागतील.';
+$lang['i_success']             = 'व्यवस्था लावण्याचे काम यशस्वीरीत्या पार पडले. आता तुम्ही install.php डिलीट करू शकता. <a href="doku.php?id=wiki:welcome">तुमच्या नविन डॉक्युविकि </a> वर जा.';
+$lang['i_failure']             = 'कॉन्फिगुरेशनच्या फाइल सुरक्षित करताना काही अडचणी आल्या आहेत. <a href="doku.php?id=wiki:welcome">तुमची नवीन डॉक्युविकि </a> वापरण्याआधी तुम्हाला ह्या फाइल स्वतः ठीक कराव्या लागतील.';
 $lang['i_policy']              = 'आरंभीची ACL पॉलिसी';
 $lang['i_pol0']                = 'मुक्त विकी ( सर्वांना वाचन, लेखन व अपलोड करण्याची परवानगी )';
 $lang['i_pol1']                = 'सार्वजनिक विकी ( सर्वांना वाचण्याची मुभा , लेखन व अपलोडची परवानगी फक्त नोंदणीकृत सदस्यांना )';
