@@ -86,7 +86,7 @@ $lang['txt_overwrt']           = 'रहेको उहि नामको फ
 $lang['lockedby']              = 'अहिले ताल्चा लगाइएको';
 $lang['lockexpire']            = 'ताल्चा अवधि सकिने :';
 $lang['js']['willexpire']            = 'तपाईलले यो पृष्ठ सम्पादन गर्न लगाउनु भएको ताल्चाको अवधि एक मिनेट भित्र सकिदै छ। \n द्वन्द हुन नदिन  पूर्वरुप वा ताल्चा समय परिवर्तन गर्नुहोस् ।';
-$lang['js']['notsavedyet']     = "तपाईले वचन गर्नु नभएको परिवर्रन हराउने छ। \n साच्चै जारी गर्नुहुन्छ ।";
+$lang['js']['notsavedyet']     = 'तपाईले वचन गर्नु नभएको परिवर्रन हराउने छ। \n साच्चै जारी गर्नुहुन्छ ।';
 $lang['rssfailed']             = 'यो फिड लिइ आउदा गल्ति भयो ।';
 $lang['nothingfound']          = 'केहि पनि भेटिएन ।';
 $lang['mediaselect']           = 'मिडिया फाइलहरू ';
@@ -128,7 +128,6 @@ $lang['lastmod']               = 'अन्तिम पटक सच्या
 $lang['by']                    = 'द्वारा ';
 $lang['deleted']               = 'हटाइएको';
 $lang['created']               = 'निर्माण गरिएको';
-$lang['restored']              = 'पुरानो संस्करण पुनर्‌प्रयोग गरिएको';
 $lang['external_edit']         = 'बाह्य सम्पादन';
 $lang['summary']               = 'सम्पादनको बारेमा';
 $lang['mail_newpage']          = 'थपिएको पृष्ठ';
@@ -191,8 +190,8 @@ $lang['i_confexists']          = '<code>%s</code> पहिले देखि 
 $lang['i_writeerr']            = '<code>%s</code> बनाउन असमर्थ । तपाईले डाइरेक्टरी / फाइल अनुमति जाच्नु पर्छ र फाइल आफैले बनाउनु पर्छ ।';
 $lang['i_badhash']             = 'पहिचान हुन नसकेको वा परिवर्तित  okuwiki.php (hash=code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - अवैध वा रित्तो मान ';
-$lang['i_success']             = 'स्थापना सफलरुपमा समाप्त भयो ।तपाई install.php मेट्न सक्नुहु्न्छ । <a href="doku.php">तपाईको नयाँ DokuWiki</a> निरन्तर गर्न सक्नुहुन्छ ।';
-$lang['i_failure']             = 'स्थापना समयमा केहि त्रुटि फेला पर्यो ।तपाईले आफैले यसलाई <a href="doku.php">तपाईको नयाँ DokuWiki</a> प्रयोग गर्नु अगि	सच्याउनुपर्ने  हुन्छ ।';
+$lang['i_success']             = 'स्थापना सफलरुपमा समाप्त भयो ।तपाई install.php मेट्न सक्नुहु्न्छ । <a href="doku.php?id=wiki:welcome">तपाईको नयाँ DokuWiki</a> निरन्तर गर्न सक्नुहुन्छ ।';
+$lang['i_failure']             = 'स्थापना समयमा केहि त्रुटि फेला पर्यो ।तपाईले आफैले यसलाई <a href="doku.php?id=wiki:welcome">तपाईको नयाँ DokuWiki</a> प्रयोग गर्नु अगि	सच्याउनुपर्ने  हुन्छ ।';
 $lang['i_policy']              = 'सुरुको ACL निति';
 $lang['i_pol0']                = 'खुल्ला विकि (पठन, लेखन , अपलोड ) सबैका लागि';
 $lang['i_pol1']                = 'Public विकि (पठन सवैका लागि,लेखन र अपलोड दर्ता गरिएका प्रयपगकर्ताका लागि ) ';
