@@ -6,7 +6,7 @@
  * @author Tiberiu Micu <tibimicu@gmx.net>
  * @author Sergiu Baltariu <s_baltariu@yahoo.com>
  * @author Emanuel-Emeric Andrași <n30@mandrivausers.ro>
- * @author Emanuel-Emeric Andraşi <em.andrasi@mandrivausers.ro>
+ * @author Emanuel-Emeric Andrași <em.andrasi@mandrivausers.ro>
  * @author Marius OLAR <olarmariusalex@gmail.com>
  * @author Marius Olar <olarmariusalex@yahoo.com>
  * @author Emanuel-Emeric Andrași <em.andrasi@mandrivausers.ro>
@@ -31,87 +31,87 @@ $lang['btn_older']             = 'mai vechi>>';
 $lang['btn_revs']              = 'Versiuni vechi';
 $lang['btn_recent']            = 'Modificări recente';
 $lang['btn_upload']            = 'Upload';
-$lang['btn_cancel']            = 'Renunţare';
+$lang['btn_cancel']            = 'Renunțare';
 $lang['btn_index']             = 'Index';
 $lang['btn_secedit']           = 'Editează';
 $lang['btn_login']             = 'Login';
 $lang['btn_logout']            = 'Logout';
 $lang['btn_admin']             = 'Admin';
 $lang['btn_update']            = 'Actualizează';
-$lang['btn_delete']            = 'Şterge';
+$lang['btn_delete']            = 'Șterge';
 $lang['btn_back']              = 'Înapoi';
 $lang['btn_backlink']          = 'Legătură anterioară';
-$lang['btn_backtomedia']       = 'Înapoi la Selecţia Mediafile';
+$lang['btn_backtomedia']       = 'Înapoi la Selecția Mediafile';
 $lang['btn_subscribe']         = 'Subscrie Modificarea Paginii';
 $lang['btn_profile']           = 'Actualizează Profil';
 $lang['btn_reset']             = 'Resetează';
 $lang['btn_resendpwd']         = 'Setează o parolă nouă';
-$lang['btn_draft']             = 'Editează schiţă';
-$lang['btn_recover']           = 'Recuperează schiţă';
-$lang['btn_draftdel']          = 'Şterge schiţă';
+$lang['btn_draft']             = 'Editează schiță';
+$lang['btn_recover']           = 'Recuperează schiță';
+$lang['btn_draftdel']          = 'Șterge schiță';
 $lang['btn_revert']            = 'Revenire';
 $lang['btn_register']          = 'Înregistrează';
 $lang['btn_apply']             = 'Aplică';
 $lang['btn_media']             = 'Administrare media';
-$lang['loggedinas']            = 'Logat ca şi';
+$lang['loggedinas']            = 'Logat ca și';
 $lang['user']                  = 'Utilizator';
 $lang['pass']                  = 'Parola';
 $lang['newpass']               = 'Parola nouă';
 $lang['oldpass']               = 'Confirmă parola curentă';
 $lang['passchk']               = 'încă o dată';
-$lang['remember']              = 'Ţine-mă minte';
+$lang['remember']              = 'Ține-mă minte';
 $lang['fullname']              = 'Nume complet';
 $lang['email']                 = 'E-Mail';
 $lang['profile']               = 'Profil Utilizator';
-$lang['badlogin']              = 'Imi pare rău, utilizatorul şi/sau parola au fost greşite.';
+$lang['badlogin']              = 'Imi pare rău, utilizatorul și/sau parola au fost greșite.';
 $lang['minoredit']             = 'Modificare Minoră';
-$lang['draftdate']             = 'Schiţă salvată automat la';
-$lang['nosecedit']             = 'Pagina s-a modificat între timp, secţiunea info a expirat, s-a încărcat pagina întreagă în loc.';
+$lang['draftdate']             = 'Schiță salvată automat la';
+$lang['nosecedit']             = 'Pagina s-a modificat între timp, secțiunea info a expirat, s-a încărcat pagina întreagă în loc.';
 $lang['regmissing']            = 'Ne pare rău, trebuie să completezi toate cîmpurile.';
 $lang['reguexists']            = 'Ne pare rău, un utilizator cu acest nume există deja logat.';
 $lang['regsuccess']            = 'Utilizatorul a fost creat. Parola a fost trimisă prin email.';
 $lang['regsuccess2']           = 'Utilizatorul a fost creat.';
-$lang['regmailfail']           = 'Se pare că a fost o eroare la trimiterea parolei prin email. Contactaţi administratorul!';
-$lang['regbadmail']            = 'Adresa de email este invalidă - dacă credeţi că este o eroare contactaţi administratorul.';
-$lang['regbadpass']            = 'Cele două parole furnizate nu sunt identice; încercaţi din nou.';
+$lang['regmailfail']           = 'Se pare că a fost o eroare la trimiterea parolei prin email. Contactați administratorul!';
+$lang['regbadmail']            = 'Adresa de email este invalidă - dacă credeți că este o eroare contactați administratorul.';
+$lang['regbadpass']            = 'Cele două parole furnizate nu sunt identice; încercați din nou.';
 $lang['regpwmail']             = 'Parola ta DokuWiki';
-$lang['reghere']               = 'Înca nu ai un cont? Fă-ţi unul';
+$lang['reghere']               = 'Înca nu ai un cont? Fă-ți unul';
 $lang['profna']                = 'Această wiki nu suportă modificarea profilului';
 $lang['profnochange']          = 'Nici o modificare; nimic de făcut.';
 $lang['profnoempty']           = 'Nu sunt admise numele sau adresa de email necompletate.';
 $lang['profchanged']           = 'Profilul de utilizator a fost actualizat succes.';
-$lang['pwdforget']             = 'Parola uitată? Luaţi una nouă';
+$lang['pwdforget']             = 'Parola uitată? Luați una nouă';
 $lang['resendna']              = 'Această wiki nu suportă retrimiterea parolei.';
 $lang['resendpwd']             = 'Setează o parolă nouă pentru';
 $lang['resendpwdmissing']      = 'Ne pare rău, trebuie completate toate câmpurile.';
 $lang['resendpwdnouser']       = 'Ne pare rău, acest utilizator nu poate fi găsit în baza de date.';
-$lang['resendpwdbadauth']      = 'Ne pare rău, acest cod de autorizare nu este corect. Verificaţi dacă aţi folosit tot link-ul de confirmare.';
+$lang['resendpwdbadauth']      = 'Ne pare rău, acest cod de autorizare nu este corect. Verificați dacă ați folosit tot link-ul de confirmare.';
 $lang['resendpwdconfirm']      = 'Un link de confirmare a fost trimis prin email.';
 $lang['resendpwdsuccess']      = 'Parola nouă';
-$lang['license']               = 'Exceptând locurile unde este altfel specificat, conţinutul acestui wiki este licenţiat sub următoarea licenţă:';
-$lang['licenseok']             = 'Notă: Prin editarea acestei pagini sunteţi de acord să vă licenţiaţi conţintul sub următoarea licenţă:';
-$lang['searchmedia']           = 'Caută numele fişierului:';
+$lang['license']               = 'Exceptând locurile unde este altfel specificat, conținutul acestui wiki este licențiat sub următoarea licență:';
+$lang['licenseok']             = 'Notă: Prin editarea acestei pagini sunteți de acord să vă licențiați conțintul sub următoarea licență:';
+$lang['searchmedia']           = 'Caută numele fișierului:';
 $lang['searchmedia_in']        = 'Caută în %s';
 $lang['txt_upload']            = 'Selectează fisierul de încărcat';
-$lang['txt_filename']          = 'Încarcă fişierul ca (opţional)';
-$lang['txt_overwrt']           = 'Suprascrie fişierul existent';
+$lang['txt_filename']          = 'Încarcă fișierul ca (opțional)';
+$lang['txt_overwrt']           = 'Suprascrie fișierul existent';
 $lang['lockedby']              = 'Momentan blocat de';
 $lang['lockexpire']            = 'Blocarea expiră la';
-$lang['js']['willexpire']      = 'Blocarea pentru editarea paginii expiră intr-un minut.\nPentru a preveni conflictele foloseşte butonul de previzualizare pentru resetarea blocării.';
+$lang['js']['willexpire']      = 'Blocarea pentru editarea paginii expiră intr-un minut.\nPentru a preveni conflictele folosește butonul de previzualizare pentru resetarea blocării.';
 $lang['js']['notsavedyet']     = 'Există modificări nesalvate, care se vor pierde.
-Doreşti să continui?';
-$lang['js']['searchmedia']     = 'Caută fişiere';
-$lang['js']['keepopen']        = 'Menţine fereastra deschisă la selecţie';
+Dorești să continui?';
+$lang['js']['searchmedia']     = 'Caută fișiere';
+$lang['js']['keepopen']        = 'Menține fereastra deschisă la selecție';
 $lang['js']['hidedetails']     = 'Ascunde Detalii';
 $lang['js']['mediatitle']      = 'Setări link';
 $lang['js']['mediadisplay']    = 'Tip link';
 $lang['js']['mediaalign']      = 'Aliniere';
 $lang['js']['mediasize']       = 'Mărime imagine';
-$lang['js']['mediatarget']     = 'Ţintă link';
+$lang['js']['mediatarget']     = 'Țintă link';
 $lang['js']['mediaclose']      = 'Închide';
 $lang['js']['mediainsert']     = 'Inserează';
-$lang['js']['mediadisplayimg'] = 'Afişează imaginea.';
-$lang['js']['mediadisplaylnk'] = 'Afişează doar linkul.';
+$lang['js']['mediadisplayimg'] = 'Afișează imaginea.';
+$lang['js']['mediadisplaylnk'] = 'Afișează doar linkul.';
 $lang['js']['mediasmall']      = 'Versiune mică';
 $lang['js']['mediamedium']     = 'Versiune medie';
 $lang['js']['medialarge']      = 'Versiune mare';
@@ -124,11 +124,11 @@ $lang['js']['medialeft']       = 'Aliniază imaginea la stânga.';
 $lang['js']['mediaright']      = 'Aliniază imaginea la dreapta.';
 $lang['js']['mediacenter']     = 'Aliniază imaginea la centru.';
 $lang['js']['medianoalign']    = 'Nu utiliza aliniere.';
-$lang['js']['nosmblinks']      = 'Legăturile către sharing-uri Windows funcţioneaza numai in Microsoft Internet Explorer.
-Puteţi însă copia şi insera legătura.';
+$lang['js']['nosmblinks']      = 'Legăturile către sharing-uri Windows funcționeaza numai in Microsoft Internet Explorer.
+Puteți însă copia și insera legătura.';
 $lang['js']['linkwiz']         = 'Asistent legătură';
 $lang['js']['linkto']          = 'Legătură la:';
-$lang['js']['del_confirm']     = 'Doriţi într-adevăr ştergerea elementelor selectate?';
+$lang['js']['del_confirm']     = 'Doriți într-adevăr ștergerea elementelor selectate?';
 $lang['js']['restore_confirm'] = 'Sunteți sigur că doriți restaurarea acestei versiuni?';
 $lang['js']['media_diff']      = 'Arată diferențele:';
 $lang['js']['media_diff_both'] = 'Unul lângă altul';
@@ -142,52 +142,52 @@ $lang['js']['media_cancel']    = 'înlătură';
 $lang['js']['media_overwrt']   = 'Suprascrie fișierele deja existente';
 $lang['rssfailed']             = 'A apărut o eroare in timpul descărcării acestui cîmp: ';
 $lang['nothingfound']          = 'Nu am găsit nimic.';
-$lang['mediaselect']           = 'Selectare fişiere media';
-$lang['fileupload']            = 'Încarcă fişier media';
-$lang['uploadsucc']            = 'Încărcare reuşită';
-$lang['uploadfail']            = 'Încărcare eşuată. Poate din cauza permisiunilor?';
-$lang['uploadwrong']           = 'Încărcare nepermisă. Extensia fişierului e nepermisă';
-$lang['uploadexist']           = 'Fişierul există deja. Nimic nu a fost făcut.';
-$lang['uploadbadcontent']      = 'Conţinutul încărcat nu corespunde extensiei fişierului %s.';
+$lang['mediaselect']           = 'Selectare fișiere media';
+$lang['fileupload']            = 'Încarcă fișier media';
+$lang['uploadsucc']            = 'Încărcare reușită';
+$lang['uploadfail']            = 'Încărcare eșuată. Poate din cauza permisiunilor?';
+$lang['uploadwrong']           = 'Încărcare nepermisă. Extensia fișierului e nepermisă';
+$lang['uploadexist']           = 'Fișierul există deja. Nimic nu a fost făcut.';
+$lang['uploadbadcontent']      = 'Conținutul încărcat nu corespunde extensiei fișierului %s.';
 $lang['uploadspam']            = 'Încărcarea a fost blocată datorită listei negre de spam.';
-$lang['uploadxss']             = 'Încărcarea a fost blocată datorită unui posibil conţinut dăunător.';
-$lang['uploadsize']            = 'Fişierul uploadat a fost prea mare. (max %s)';
-$lang['deletesucc']            = 'Fişierul "%s" a fost şters.';
-$lang['deletefail']            = '"%s" nu a putut fi şters - verificaţi drepturile.';
-$lang['mediainuse']            = 'Fişierul "%s" nu a fost şters - este încă în uz.';
-$lang['namespaces']            = 'Spaţii de nume';
-$lang['mediafiles']            = 'Fişiere disponibile în';
-$lang['accessdenied']          = 'Nu vă este permis să vizualizaţi această pagină.';
-$lang['mediausage']            = 'Folosiţi următoarea sintaxă pentru a face referinţă la acest fişier:';
-$lang['mediaview']             = 'Vizualizează fişierul original';
+$lang['uploadxss']             = 'Încărcarea a fost blocată datorită unui posibil conținut dăunător.';
+$lang['uploadsize']            = 'Fișierul uploadat a fost prea mare. (max %s)';
+$lang['deletesucc']            = 'Fișierul "%s" a fost șters.';
+$lang['deletefail']            = '"%s" nu a putut fi șters - verificați drepturile.';
+$lang['mediainuse']            = 'Fișierul "%s" nu a fost șters - este încă în uz.';
+$lang['namespaces']            = 'Spații de nume';
+$lang['mediafiles']            = 'Fișiere disponibile în';
+$lang['accessdenied']          = 'Nu vă este permis să vizualizați această pagină.';
+$lang['mediausage']            = 'Folosiți următoarea sintaxă pentru a face referință la acest fișier:';
+$lang['mediaview']             = 'Vizualizează fișierul original';
 $lang['mediaroot']             = 'root';
-$lang['mediaupload']           = 'Încarcă un fişier in acest spaţiu de nume. Pentru a crea sub-spaţii de nume, adaugă-le la fişierul de încărcat, separate de doua puncte (:).';
-$lang['mediaextchange']        = 'Extensia fişierului a fost modificată din .%s în .%s!';
-$lang['reference']             = 'Referinţă pentru';
-$lang['ref_inuse']             = 'Fişierul nu a putut fi şters întrucât este folosit încă de următoarele pagini:';
-$lang['ref_hidden']            = 'Nu aveţi permisiunea să citiţi o parte din referinţele din pagină.';
+$lang['mediaupload']           = 'Încarcă un fișier in acest spațiu de nume. Pentru a crea sub-spații de nume, adaugă-le la fișierul de încărcat, separate de doua puncte (:).';
+$lang['mediaextchange']        = 'Extensia fișierului a fost modificată din .%s în .%s!';
+$lang['reference']             = 'Referință pentru';
+$lang['ref_inuse']             = 'Fișierul nu a putut fi șters întrucât este folosit încă de următoarele pagini:';
+$lang['ref_hidden']            = 'Nu aveți permisiunea să citiți o parte din referințele din pagină.';
 $lang['hits']                  = 'Hituri';
 $lang['quickhits']             = 'Nume de pagini potrivite';
 $lang['toc']                   = 'Cuprins';
 $lang['current']               = 'curent';
 $lang['yours']                 = 'Versiunea ta';
-$lang['diff']                  = 'arată diferenţele faţă de versiunea curentă';
-$lang['diff2']                 = 'Arată diferenţele dintre versiunile selectate';
+$lang['diff']                  = 'arată diferențele față de versiunea curentă';
+$lang['diff2']                 = 'Arată diferențele dintre versiunile selectate';
 $lang['difflink']              = 'Link către această vizualizare comparativă';
 $lang['diff_type']             = 'Vezi diferențe:';
 $lang['diff_inline']           = 'Succesiv';
 $lang['diff_side']             = 'Alăturate';
 $lang['line']                  = 'Linia';
 $lang['breadcrumb']            = 'Traseu';
-$lang['youarehere']            = 'Sunteţi aici';
+$lang['youarehere']            = 'Sunteți aici';
 $lang['lastmod']               = 'Ultima modificare';
 $lang['by']                    = 'de către';
-$lang['deleted']               = 'şters';
+$lang['deleted']               = 'șters';
 $lang['created']               = 'creat';
-$lang['restored']              = 'versiune veche restaurată';
+$lang['restored']              = 'versiune veche restaurată (%s)';
 $lang['external_edit']         = 'editare externă';
 $lang['summary']               = 'Editează sumarul';
-$lang['noflash']               = 'Plugin-ul <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> este necesar pentru afişarea corectă a conţinutului.';
+$lang['noflash']               = 'Plugin-ul <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> este necesar pentru afișarea corectă a conținutului.';
 $lang['download']              = 'Bloc descărcări';
 $lang['tools']                 = 'Unelte';
 $lang['user_tools']            = 'Unelte utilizator';
@@ -196,14 +196,14 @@ $lang['page_tools']            = 'Unelte Pagină';
 $lang['skip_to_content']       = 'sari la conținut';
 $lang['mail_newpage']          = 'pagina adăugată:';
 $lang['mail_changed']          = 'page schimbată:';
-$lang['mail_subscribe_list']   = 'pagini modificate în spaţiul de nume:';
+$lang['mail_subscribe_list']   = 'pagini modificate în spațiul de nume:';
 $lang['mail_new_user']         = 'utilizator nou';
-$lang['mail_upload']           = 'fişier încărcat:';
+$lang['mail_upload']           = 'fișier încărcat:';
 $lang['changes_type']          = 'Vizualizare modificări';
 $lang['pages_changes']         = 'Pagini';
 $lang['media_changes']         = 'Fișiere media';
-$lang['both_changes']          = 'Ambele pagini şi fişiere media';
-$lang['qb_bold']               = 'Text Îngroşat';
+$lang['both_changes']          = 'Ambele pagini și fișiere media';
+$lang['qb_bold']               = 'Text Îngroșat';
 $lang['qb_italic']             = 'Text Italic';
 $lang['qb_underl']             = 'Text Subliniat';
 $lang['qb_code']               = 'Text Cod';
@@ -214,29 +214,29 @@ $lang['qb_h3']                 = 'Titlu de Nivel 3';
 $lang['qb_h4']                 = 'Titlu de Nivel 4';
 $lang['qb_h5']                 = 'Titlu de Nivel 5';
 $lang['qb_h']                  = 'Titlu';
-$lang['qb_hs']                 = 'Selectaţi Titlul';
+$lang['qb_hs']                 = 'Selectați Titlul';
 $lang['qb_hplus']              = 'Titlu mai mare';
 $lang['qb_hminus']             = 'Titlu mai mic';
-$lang['qb_hequal']             = 'Titlu de acelaşi nivel';
+$lang['qb_hequal']             = 'Titlu de același nivel';
 $lang['qb_link']               = 'Legătură internă';
 $lang['qb_extlink']            = 'Legătura externă';
 $lang['qb_hr']                 = 'Linie Orizontal';
 $lang['qb_ol']                 = 'Listă Ordonată';
 $lang['qb_ul']                 = 'Listă Neordoată';
-$lang['qb_media']              = 'Adaugă imagini şi alte fişiere';
+$lang['qb_media']              = 'Adaugă imagini și alte fișiere';
 $lang['qb_sig']                = 'Inserează semnătură';
 $lang['qb_smileys']            = 'Smiley-uri';
 $lang['qb_chars']              = 'Caractere speciale';
-$lang['upperns']               = 'sari la numele de spaţiu părinte';
+$lang['upperns']               = 'sari la numele de spațiu părinte';
 $lang['admin_register']        = 'Adaugă utilizator nou';
 $lang['metaedit']              = 'Editează Metadata';
-$lang['metasaveerr']           = 'Scrierea metadatelor a eşuat';
+$lang['metasaveerr']           = 'Scrierea metadatelor a eșuat';
 $lang['metasaveok']            = 'Metadatele au fost salvate';
 $lang['img_backto']            = 'Înapoi la';
 $lang['img_title']             = 'Titlu';
 $lang['img_caption']           = 'Legendă';
 $lang['img_date']              = 'Data';
-$lang['img_fname']             = 'Nume fişier';
+$lang['img_fname']             = 'Nume fișier';
 $lang['img_fsize']             = 'Dimensiune';
 $lang['img_artist']            = 'Fotograf';
 $lang['img_copyr']             = 'Copyright';
@@ -248,47 +248,47 @@ $lang['img_height']            = 'Înălțime';
 $lang['img_manager']           = 'Vizualizează în administratorul media';
 $lang['subscr_subscribe_success'] = 'Adăugat %s la lista de abonare pentru %s';
 $lang['subscr_subscribe_error'] = 'Eroare la adăugarea %s la lista de abonare pentru %s';
-$lang['subscr_subscribe_noaddress'] = 'Nu există adresa asociată cu logarea dvs., nu puteţi fi adăugat la lista de abonare';
-$lang['subscr_unsubscribe_success'] = 'Şters %s din lista de abonare pentru %s';
-$lang['subscr_unsubscribe_error'] = 'Eroare la ştergerea %s din lista de abonare pentru %s';
+$lang['subscr_subscribe_noaddress'] = 'Nu există adresa asociată cu logarea dvs., nu puteți fi adăugat la lista de abonare';
+$lang['subscr_unsubscribe_success'] = 'Șters %s din lista de abonare pentru %s';
+$lang['subscr_unsubscribe_error'] = 'Eroare la ștergerea %s din lista de abonare pentru %s';
 $lang['subscr_already_subscribed'] = '%s este deja abonat la %s';
 $lang['subscr_not_subscribed'] = '%s nu este abonat la %s';
-$lang['subscr_m_not_subscribed'] = 'Momentan nu sunteţi abonat la pagina curentă sau la numele de spaţiu.';
+$lang['subscr_m_not_subscribed'] = 'Momentan nu sunteți abonat la pagina curentă sau la numele de spațiu.';
 $lang['subscr_m_new_header']   = 'Adaugă abonare';
 $lang['subscr_m_current_header'] = 'Abonări curente';
-$lang['subscr_m_unsubscribe']  = 'Dezabonaţi-vă';
-$lang['subscr_m_subscribe']    = 'Abonaţi-vă';
-$lang['subscr_m_receive']      = 'Primiţi';
+$lang['subscr_m_unsubscribe']  = 'Dezabonați-vă';
+$lang['subscr_m_subscribe']    = 'Abonați-vă';
+$lang['subscr_m_receive']      = 'Primiți';
 $lang['subscr_style_every']    = 'email la ficare schimbare';
 $lang['subscr_style_digest']   = 'digerează email la schimbări pentru fiecare pagină (la fiecare %.2f zile)';
 $lang['subscr_style_list']     = 'lista paginilor schimbate de la ultimul email (la fiecare %.2f zile)';
-$lang['authmodfailed']         = 'Configuraţia autentificării utilizatorului este eronată. Anunţaţi Wiki Admin-ul.';
-$lang['authtempfail']          = 'Autentificarea utilizatorului este temporar indisponibilă. Anunţaţi Wiki Admin-ul.';
+$lang['authmodfailed']         = 'Configurația autentificării utilizatorului este eronată. Anunțați Wiki Admin-ul.';
+$lang['authtempfail']          = 'Autentificarea utilizatorului este temporar indisponibilă. Anunțați Wiki Admin-ul.';
 $lang['authpwdexpire']         = 'Parola vă va expira în %d zile, ar trebui să o schimbați curând.';
-$lang['i_chooselang']          = 'Alegeţi limba';
+$lang['i_chooselang']          = 'Alegeți limba';
 $lang['i_installer']           = 'DokuWiki Installer';
 $lang['i_wikiname']            = 'Numele Wiki';
 $lang['i_enableacl']           = 'Activează ACL (recomandat)';
 $lang['i_superuser']           = 'Superutilizator';
-$lang['i_problems']            = 'Programul de instalare a găsit câteva probleme, indicate mai jos. Nu puteţi continua până nu le rezolvaţi.';
-$lang['i_modified']            = 'Din motive de securitate, acest script va funcţiona doar cu o instalare nouă şi nemodificată a Docuwiki.
-Puteţi fie să extrageţi din nou fişierele din arhiva descărcată fie să consultaţi instrucţiunile de instalare Dokuwiki la <a href="http://dokuwiki.org/install">';
-$lang['i_funcna']              = 'Funcţia PHP <code>%s</code> nu este disponibilă. Probabil provider-ul dvs. a inactivat-o pentru un motiv oarecare.';
-$lang['i_phpver']              = 'Versiunea dvs. de PHP <code>%s</code> este mai veche decât cea necesară (<code>%s</code>). Trebuie să vă actualizaţi instalarea PHP.';
-$lang['i_permfail']            = '<code>%s</code> nu poate fi scris de către DokuWiki. Trebuie să modificaţi drepturile acestui director!';
+$lang['i_problems']            = 'Programul de instalare a găsit câteva probleme, indicate mai jos. Nu puteți continua până nu le rezolvați.';
+$lang['i_modified']            = 'Din motive de securitate, acest script va funcționa doar cu o instalare nouă și nemodificată a Docuwiki.
+Puteți fie să extrageți din nou fișierele din arhiva descărcată fie să consultați instrucțiunile de instalare Dokuwiki la <a href="http://dokuwiki.org/install">';
+$lang['i_funcna']              = 'Funcția PHP <code>%s</code> nu este disponibilă. Probabil provider-ul dvs. a inactivat-o pentru un motiv oarecare.';
+$lang['i_phpver']              = 'Versiunea dvs. de PHP <code>%s</code> este mai veche decât cea necesară (<code>%s</code>). Trebuie să vă actualizați instalarea PHP.';
+$lang['i_permfail']            = '<code>%s</code> nu poate fi scris de către DokuWiki. Trebuie să modificați drepturile acestui director!';
 $lang['i_confexists']          = '<code>%s</code> există deja';
-$lang['i_writeerr']            = 'Nu s-a putut crea <code>%s</code>. Trebuie să verificaţi drepturile directorului/fişierului şi să creaţi fişierul manual.';
+$lang['i_writeerr']            = 'Nu s-a putut crea <code>%s</code>. Trebuie să verificați drepturile directorului/fișierului și să creați fișierul manual.';
 $lang['i_badhash']             = 'dokuwiki.php nu a fost recunoscut sau a fost modificat (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - valoare nepemisă sau neintrodusă';
-$lang['i_success']             = 'Configurarea a fost finalizată cu succes. Acum puteţi sterge fişierul install.php. Continuaţi cu <a href="doku.php">your new DokuWiki</a>.';
-$lang['i_failure']             = 'Au apărut erori la scrierea fişierelor de configurare. Va trebui să le corectaţi manual înainte de a putea folosi <a href="doku.php">your new DokuWiki</a>.';
-$lang['i_policy']              = 'Politica ACL iniţială';
-$lang['i_pol0']                = 'Wiki Deschisă (citeşte, scrie şi încarcă oricine)';
-$lang['i_pol1']                = 'Wiki Deschisă (citeste oricine, scrie şi încarcă doar utilizatorul înregistrat)';
-$lang['i_pol2']                = 'Wiki Închisă (citeşte, scrie şi încarcă doar utilizatorul înregistrat)';
+$lang['i_success']             = 'Configurarea a fost finalizată cu succes. Acum puteți sterge fișierul install.php. Continuați cu <a href="doku.php?id=wiki:welcome">your new DokuWiki</a>.';
+$lang['i_failure']             = 'Au apărut erori la scrierea fișierelor de configurare. Va trebui să le corectați manual înainte de a putea folosi <a href="doku.php?id=wiki:welcome">your new DokuWiki</a>.';
+$lang['i_policy']              = 'Politica ACL inițială';
+$lang['i_pol0']                = 'Wiki Deschisă (citește, scrie și încarcă oricine)';
+$lang['i_pol1']                = 'Wiki Deschisă (citeste oricine, scrie și încarcă doar utilizatorul înregistrat)';
+$lang['i_pol2']                = 'Wiki Închisă (citește, scrie și încarcă doar utilizatorul înregistrat)';
 $lang['i_retry']               = 'Încearcă din nou';
-$lang['i_license']             = 'Vă rugăm alegeţi licenţa sub care doriţi să vă licenţiaţi materialul:';
-$lang['recent_global']         = 'Acum vizualizaţi modificările în interiorul numelui de spaţiu <b>%s</b>. De asemenea puteţi <a href="%s">vizualiza modificările recente ale întregului wiki</a>.';
+$lang['i_license']             = 'Vă rugăm alegeți licența sub care doriți să vă licențiați materialul:';
+$lang['recent_global']         = 'Acum vizualizați modificările în interiorul numelui de spațiu <b>%s</b>. De asemenea puteți <a href="%s">vizualiza modificările recente ale întregului wiki</a>.';
 $lang['years']                 = 'acum %d ani';
 $lang['months']                = 'acum %d luni';
 $lang['weeks']                 = 'acum %d săptămâni';
@@ -296,7 +296,7 @@ $lang['days']                  = 'acum %d zile';
 $lang['hours']                 = 'acum %d ore';
 $lang['minutes']               = 'acum %d minute';
 $lang['seconds']               = 'acum %d secunde';
-$lang['wordblock']             = 'Modificarea dvs. nu au fost salvate deoarece conţine text blocat (spam).';
+$lang['wordblock']             = 'Modificarea dvs. nu au fost salvate deoarece conține text blocat (spam).';
 $lang['media_uploadtab']       = 'Încarcă';
 $lang['media_searchtab']       = 'Căutare';
 $lang['media_file']            = 'Fișier';
