@@ -177,7 +177,7 @@ $lang['lastmod']               = 'Zadnja sprememba';
 $lang['by']                    = 'uporabnika';
 $lang['deleted']               = 'odstranjena';
 $lang['created']               = 'ustvarjena';
-$lang['restored']              = 'povrnjena stara različica';
+$lang['restored']              = 'povrnjena stara različica (%s)';
 $lang['external_edit']         = 'urejanje v zunanjem urejevalniku';
 $lang['summary']               = 'Povzetek urejanja';
 $lang['noflash']               = 'Za prikaz vsebine je treba namestiti <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>';
@@ -271,8 +271,8 @@ $lang['i_confexists']          = 'Predmet <code>%s</code> že obstaja.';
 $lang['i_writeerr']            = 'Ni mogoče ustvariti predmeta <code>%s</code>. Preveriti je treba dovoljenja datotek in map in nato ustvariti datoteko ročno.';
 $lang['i_badhash']             = 'nepoznana ali spremenjena datoteka dokuwiki.php (razpršilo=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - neveljavna ali prazna vrednost';
-$lang['i_success']             = 'Nastavitev je uspešno končana. Datoteko install.php lahko sedaj izbrišete. Nadaljujte v <a href="doku.php">novi DokuWiki</a>.';
-$lang['i_failure']             = 'Med zapisovanjem nastavitvenih datotek je prišlo do napak. Preden lahko uporabite vaš <a href="doku.php">DokuWiki</a>, jih je treba odpraviti.';
+$lang['i_success']             = 'Nastavitev je uspešno končana. Datoteko install.php lahko sedaj izbrišete. Nadaljujte v <a href="doku.php?id=wiki:welcome">novi DokuWiki</a>.';
+$lang['i_failure']             = 'Med zapisovanjem nastavitvenih datotek je prišlo do napak. Preden lahko uporabite vaš <a href="doku.php?id=wiki:welcome">DokuWiki</a>, jih je treba odpraviti.';
 $lang['i_policy']              = 'Začetna določila ACL';
 $lang['i_pol0']                = 'Odprt Wiki (branje, zapis, nalaganje datotek je javno za vse)';
 $lang['i_pol1']                = 'Javni Wiki (branje za vse, zapis in nalaganje datotek za prijavljene uporabnike)';
