@@ -93,7 +93,7 @@ $lang['txt_overwrt']           = 'Zëvendëso skedarin ekzistues';
 $lang['lockedby']              = 'Kyçur momentalisht nga';
 $lang['lockexpire']            = 'Kyçi skadon në';
 $lang['js']['willexpire']            = 'Kyçi juaj për redaktimin e kësaj faqeje është duke skaduar.\nPër të shmangur konflikte përdorni butonin Shiko Paraprakisht për të rivendosur kohën e kyçjes.';
-$lang['js']['notsavedyet']     = "Ndryshimet e paruajtura do të humbasin.\nVazhdo me të vërtetë?";
+$lang['js']['notsavedyet']     = 'Ndryshimet e paruajtura do të humbasin.\nVazhdo me të vërtetë?';
 $lang['rssfailed']             = 'Ndoshi një gabim gjatë kapjes së këtij lajmi:';
 $lang['nothingfound']          = 'Nuk u gjet asgjë.';
 $lang['mediaselect']           = 'Skedarët e Medias';
@@ -140,7 +140,7 @@ $lang['lastmod']               = 'Redaktuar për herë të fundit';
 $lang['by']                    = 'nga';
 $lang['deleted']               = 'u fshi';
 $lang['created']               = 'u krijua';
-$lang['restored']              = 'Kthehu tek një version i vjetër';
+$lang['restored']              = 'Kthehu tek një version i vjetër (%s)';
 $lang['external_edit']         = 'redaktim i jashtëm';
 $lang['summary']               = 'Përmbledhja redaktimit';
 $lang['noflash']               = 'Nevojitet <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> për të paraqitur këtë përmbajtje.';
@@ -204,8 +204,6 @@ $lang['subscr_m_unsubscribe']  = 'Fshi Abonimin';
 $lang['subscr_m_subscribe']    = 'Abonohu';
 $lang['subscr_m_receive']      = 'Mer';
 $lang['subscr_style_every']    = 'email mbi çdo ndryshim';
-$lang['subscr_style_digest']   = 'pasqyro email-e ndryshimi pér çdo faqe';
-$lang['subscr_style_list']     = 'listë e faqeve të ndryshuara që nga emaili i fundit';
 $lang['authmodfailed']         = 'Konfigurim i gabuar i autentikimit të përdoruesit. Ju lutem informoni Administratorin tuaj të Wiki-it.';
 $lang['authtempfail']          = 'Autentikimi i përdoruesve është përkohësisht i padisponueshëm. Nëse kjo gjendje vazhdon, ju lutemi të informoni Administratorin tuaj të Wiki-it.';
 $lang['i_chooselang']          = 'Zgjidhni gjuhën tuaj';
@@ -223,8 +221,8 @@ $lang['i_confexists']          = '<code>%s</code> ekziston njëherë';
 $lang['i_writeerr']            = '<code>%s</code> nuk mundi të krijohej. Duhet të kontrolloni lejet e dirkektorisë/skedarit dhe ta krijoni skedarin manualisht.';
 $lang['i_badhash']             = 'dokuwiki.php e panjohur ose e ndryshuar (hash=code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - vlerë e palejuar ose boshe';
-$lang['i_success']             = 'Konfigurimi u mbarua me sukses. Tani mund ta fshini skedarin install.php. Vazhdoni tek <a href="doku.php">DokuWiki juaj i ri.</a>.';
-$lang['i_failure']             = 'Ndodhën disa gabime gjatë shkrimit të skedarit të konfigurimit. Do t\'ju duhet t\'i rregulloni manualisht para se të përdorni <a href="doku.php">DokuWiki-in tuaj të ri.</a>.';
+$lang['i_success']             = 'Konfigurimi u mbarua me sukses. Tani mund ta fshini skedarin install.php. Vazhdoni tek <a href="doku.php?id=wiki:welcome">DokuWiki juaj i ri.</a>.';
+$lang['i_failure']             = 'Ndodhën disa gabime gjatë shkrimit të skedarit të konfigurimit. Do t\'ju duhet t\'i rregulloni manualisht para se të përdorni <a href="doku.php?id=wiki:welcome">DokuWiki-in tuaj të ri.</a>.';
 $lang['i_policy']              = 'Veprimi fillestar ACL';
 $lang['i_pol0']                = 'Wiki i Hapur (lexim, shkrim, ngarkim për këdo)';
 $lang['i_pol1']                = 'Wiki Publike (lexim për këdo, shkrim dhe ngarkim për përdoruesit e regjistruar)';
