@@ -162,7 +162,7 @@ $lang['lastmod']               = 'Последњи пут мењано';
 $lang['by']                    = 'од';
 $lang['deleted']               = 'избрисано';
 $lang['created']               = 'направљено';
-$lang['restored']              = 'стара верзија повраћена';
+$lang['restored']              = 'стара верзија повраћена (%s)';
 $lang['external_edit']         = 'спољна измена';
 $lang['summary']               = 'Сажетак измене';
 $lang['noflash']               = 'За приказивање ове врсте материјала потребан вам је <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
@@ -244,8 +244,8 @@ $lang['i_confexists']          = '<code>%s</code> већ постоји';
 $lang['i_writeerr']            = 'Не могу да направим <code>%s</code>. Проверите дозволе а затим ручно направите ову датотеку.';
 $lang['i_badhash']             = 'dokuwiki.php није препознат или је измењен (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - недозвољена или празна вредност';
-$lang['i_success']             = 'Подешавања су завршена. Сада можете обрисати датотеку install.php. Наставите у <a href="doku.php">Ваш нови DokuWiki</a>.';
-$lang['i_failure']             = 'Појавили су се проблеми при писању датотеке са подешавањима. Требало би да их ручно исправите пре него што ћете моћи да користите <a href="doku.php">Ваш нови DokuWiki</a>.';
+$lang['i_success']             = 'Подешавања су завршена. Сада можете обрисати датотеку install.php. Наставите у <a href="doku.php?id=wiki:welcome">Ваш нови DokuWiki</a>.';
+$lang['i_failure']             = 'Појавили су се проблеми при писању датотеке са подешавањима. Требало би да их ручно исправите пре него што ћете моћи да користите <a href="doku.php?id=wiki:welcome">Ваш нови DokuWiki</a>.';
 $lang['i_policy']              = 'Иницијалне корисничке дозволе';
 $lang['i_pol0']                = 'Отворени вики (читање, писање, слање датотека за све)';
 $lang['i_pol1']                = 'Јавни вики (читање за све, писање и слање датотека само за регистроване кориснике)';
