@@ -97,7 +97,7 @@ $lang['txt_overwrt']           = 'เขียนทับไฟล์ที่
 $lang['lockedby']              = 'ตอนนี้ถูกล๊อคโดย';
 $lang['lockexpire']            = 'การล๊อคจะหมดอายุเมื่อ';
 $lang['js']['willexpire']            = 'การล๊อคเพื่อแก้ไขหน้านี้กำลังจะหมดเวลาในอีก \n นาที เพื่อที่จะหลีกเลี่ยงข้อขัดแย้งให้ใช้ปุ่ม "Preview" เพื่อรีเซ็ทเวลาใหม่';
-$lang['js']['notsavedyet']     = "การแก้ไขที่ไม่ได้บันทึกจะสูญหาย \n ต้องการทำต่อจริงๆหรือ?";
+$lang['js']['notsavedyet']     = 'การแก้ไขที่ไม่ได้บันทึกจะสูญหาย \n ต้องการทำต่อจริงๆหรือ?';
 $lang['rssfailed']             = 'มีข้อผิดพลาดขณะดูดฟีดนี้';
 $lang['nothingfound']          = 'ไม่พบสิ่งใด';
 $lang['mediaselect']           = 'ไฟล์สื่อ';
@@ -144,7 +144,7 @@ $lang['lastmod']               = 'แก้ไขครั้งล่าสุ
 $lang['by']                    = 'โดย';
 $lang['deleted']               = 'ถูกถอดออก';
 $lang['created']               = 'ถูกสร้าง';
-$lang['restored']              = 'ย้อนไปรุ่นก่อนหน้า';
+$lang['restored']              = 'ย้อนไปรุ่นก่อนหน้า (%s)';
 $lang['external_edit']         = 'แก้ไขภายนอก';
 $lang['summary']               = 'สรุป(หมายเหตุ)การแก้ไขนี้';
 $lang['noflash']               = 'ต้องการตัวเล่นแฟลช <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> เพื่อแสดงผลเนื้อหานี้';
