@@ -169,7 +169,7 @@ $lang['lastmod']               = 'В останнє змінено';
 $lang['by']                    = ' ';
 $lang['deleted']               = 'знищено';
 $lang['created']               = 'створено';
-$lang['restored']              = 'відновлено стару ревізію';
+$lang['restored']              = 'відновлено стару ревізію (%s)';
 $lang['external_edit']         = 'зовнішнє редагування';
 $lang['summary']               = 'Підсумок змін';
 $lang['noflash']               = 'Для перегляду цієї сторінки необхідно встановити <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
@@ -253,9 +253,9 @@ $lang['i_writeerr']            = 'Неможливо створити <code>%s</
 $lang['i_badhash']             = 'Невпізнаний або модифікований dokuwiki.php (hash=<code>%s</code>)';
 $lang['i_badval']              = '<code>%s</code> - невірне або пусте значення.';
 $lang['i_success']             = 'Налаштування завершено. Ви можете знищити файл install.php.
-Перейдіть до <a href="doku.php">вашої нової ДокуВікі</a>';
+Перейдіть до <a href="doku.php?id=wiki:welcome">вашої нової ДокуВікі</a>';
 $lang['i_failure']             = 'При збереженні файлу конфігурації виникли помилки. Можливо вам доведеться виправити їх самостійно
-до початку використання <a href="doku.php">вашої нової ДокуВікі</a>.';
+до початку використання <a href="doku.php?id=wiki:welcome">вашої нової ДокуВікі</a>.';
 $lang['i_policy']              = 'Початкова політика ACL';
 $lang['i_pol0']                = 'Відкрита Вікі (читання, запис та завантаження файлів для всіх)';
 $lang['i_pol1']                = 'Публічна Вікі (читання для всіх, запис та завантаження для зареєстрованих користувачів)';
