@@ -38,7 +38,7 @@ $lang['btn_admin']  = 'Quản lý';
 $lang['btn_update'] = 'Cập nhật';
 $lang['btn_delete'] = 'Xoá';
 $lang['btn_back']              = 'Quay lại';
-$lang['btn_backlink']          = "Liên kết tới đây";
+$lang['btn_backlink']          = 'Liên kết tới đây';
 $lang['btn_profile']           = 'Cập nhật hồ sơ';
 $lang['btn_reset']             = 'Làm lại';
 $lang['btn_resendpwd']         = 'Gửi mật khẩu mới';
@@ -101,7 +101,7 @@ $lang['lockedby']     = 'Đang khoá bởi';
 $lang['lockexpire']   = 'Sẽ được mở khóa vào lúc';
 
 $lang['js']['willexpire']   = 'Trong một phút nữa bài viết sẽ được mở khóa để cho phép người khác chỉnh sửa.\nĐể tránh xung đột, bạn nên bấm nút Duyệt trước để lập lại thời gian khoá bài';
-$lang['js']['notsavedyet'] = "Hiện có những thay đổi chưa được bảo lưu, và sẽ mất.\nBạn thật sự muốn tiếp tục?";
+$lang['js']['notsavedyet'] = 'Hiện có những thay đổi chưa được bảo lưu, và sẽ mất.\nBạn thật sự muốn tiếp tục?';
 $lang['js']['searchmedia']     = 'Tìm kiếm tập tin';
 $lang['js']['keepopen']        = 'Giữ cửa sổ đang mở trên lựa chọn';
 $lang['js']['hidedetails']     = 'Ẩn thông tin chi tiết';
@@ -126,7 +126,7 @@ $lang['js']['medialeft']       = 'Căn ảnh sang trái.';
 $lang['js']['mediaright']      = 'Căn ảnh sang phải.';
 $lang['js']['mediacenter']     = 'Cản ảnh ra giữa.';
 $lang['js']['medianoalign']    = 'Không căn.';
-$lang['js']['nosmblinks'] = "Nối với các Windows shares chỉ có hiệu lực với Microsoft Internet Explorer.\nBạn vẫn có thể sao và chép các mốc nối.";
+$lang['js']['nosmblinks'] = 'Nối với các Windows shares chỉ có hiệu lực với Microsoft Internet Explorer.\nBạn vẫn có thể sao và chép các mốc nối.';
 $lang['js']['linkwiz']         = 'Hộp thoại liên kết';
 $lang['js']['linkto']          = 'Liên kết tới:';
 $lang['js']['del_confirm']= 'Xoá mục này?';
@@ -176,7 +176,7 @@ $lang['lastmod']    = 'Thời điểm thay đổi';
 $lang['by']         = 'do';
 $lang['deleted']    = 'bị xoá';
 $lang['created']    = 'được tạo ra';
-$lang['restored']   = 'phiên bản cũ đã được khôi phục';
+$lang['restored']   = 'phiên bản cũ đã được khôi phục (%s)';
 $lang['external_edit']         = 'external edit';
 $lang['summary']    = 'Tóm tắt biên soạn';
 $lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> cần được cài để có thể xem nội dung này.';
