@@ -54,7 +54,8 @@ $dokuwiki_hash = array(
     '2011-05-25'   => '4241865472edb6fa14a1227721008072',
     '2011-11-10'   => 'b46ff19a7587966ac4df61cbab1b8b31',
     '2012-01-25'   => '72c083c73608fc43c586901fd5dabb74',
-    '2012-09-10'   => 'eb0b3fc90056fbc12bac6f49f7764df3'
+    '2012-09-10'   => 'eb0b3fc90056fbc12bac6f49f7764df3',
+    '2013-05-10'   => '7b62b75245f57f122d3e0f8ed7989623',
 );
 
 
@@ -96,8 +97,8 @@ header('Content-Type: text/html; charset=utf-8');
 </head>
 <body style="">
     <h1 style="float:left">
-        <img src="lib/exe/fetch.php?media=wiki:dokuwiki-128.png&amp;w=64"
-             style="vertical-align: middle;" alt="" />
+        <img src="lib/exe/fetch.php?media=wiki:dokuwiki-128.png"
+             style="vertical-align: middle;" alt="" height="64" width="64" />
         <?php echo $lang['i_installer']?>
     </h1>
     <div style="float:right; margin: 1em;">
@@ -167,6 +168,7 @@ function print_form($d){
     $d = array_map('htmlspecialchars',$d);
 
     if(!isset($d['acl'])) $d['acl']=1;
+    if(!isset($d['pop'])) $d['pop']=1;
 
     ?>
     <form action="" method="post">
@@ -210,12 +212,12 @@ function print_form($d){
         <fieldset>
             <p><?php echo $lang['i_license']?></p>
             <?php
-            array_unshift($license,array('name' => 'None', 'url'=>''));
+            array_push($license,array('name' => $lang['i_license_none'], 'url'=>''));
             if(empty($d['license'])) $d['license'] = 'cc-by-sa';
             foreach($license as $key => $lic){
                 echo '<label for="lic_'.$key.'">';
                 echo '<input type="radio" name="d[license]" value="'.htmlspecialchars($key).'" id="lic_'.$key.'"'.
-                     (($d['license'] == $key)?' checked="checked"':'').'>';
+                     (($d['license'] === $key)?' checked="checked"':'').'>';
                 echo htmlspecialchars($lic['name']);
                 if($lic['url']) echo ' <a href="'.$lic['url'].'" target="_blank"><sup>[?]</sup></a>';
                 echo '</label>';
@@ -223,6 +225,14 @@ function print_form($d){
             ?>
         </fieldset>
 
+        <fieldset>
+            <p><?php echo $lang['i_pop_field']?></p>
+            <label for="pop">
+                <input type="checkbox" name="d[pop]" id="pop" <?php echo(($d['pop'] ? ' checked="checked"' : ''));?> />
+                <?php echo $lang['i_pop_label']?> <a href="http://www.dokuwiki.org/popularity" target="_blank"><sup>[?]</sup></a>
+            </label>
+        </fieldset>
+
     </fieldset>
     <fieldset id="process">
         <input class="button" type="submit" name="submit" value="<?php echo $lang['btn_save']?>" />
@@ -376,6 +386,30 @@ EOT;
         }
         $ok = $ok && fileWrite(DOKU_LOCAL.'acl.auth.php', $output);
     }
+
+    // enable popularity submission
+    if($d['pop']){
+        @touch(DOKU_INC.'data/cache/autosubmit.txt');
+    }
+
+    // disable auth plugins til needed
+    $output = <<<EOT
+<?php
+/*
+ * Local plugin enable/disable settings
+ *
+ * Auto-generated by install script
+ * Date: $now
+ */
+
+\$plugins['authad']    = 0;
+\$plugins['authldap']  = 0;
+\$plugins['authmysql'] = 0;
+\$plugins['authpgsql'] = 0;
+
+EOT;
+    $ok = $ok && fileWrite(DOKU_LOCAL.'plugins.local.php', $output);
+
     return $ok;
 }
 
@@ -495,7 +529,7 @@ function check_functions(){
                          'ob_start opendir parse_ini_file readfile realpath '.
                          'rename rmdir serialize session_start unlink usleep '.
                          'preg_replace file_get_contents htmlspecialchars_decode '.
-                         'spl_autoload_register stream_select fsockopen');
+                         'spl_autoload_register stream_select fsockopen pack');
 
     if (!function_exists('mb_substr')) {
         $funcs[] = 'utf8_encode';
