@@ -117,11 +117,3 @@ var dw_acl = {
 };
 
 jQuery(dw_acl.init);
-
-var acl = {
-    init: DEPRECATED_WRAP(dw_acl.init, dw_acl),
-    userselhandler: DEPRECATED_WRAP(dw_acl.userselhandler, dw_acl),
-    loadinfo: DEPRECATED_WRAP(dw_acl.loadinfo, dw_acl),
-    parseatt: DEPRECATED_WRAP(dw_acl.parseatt, dw_acl),
-    treehandler: DEPRECATED_WRAP(dw_acl.treehandler, dw_acl)
-};
