@@ -6,6 +6,7 @@
  * @author carles.bellver@gmail.com
  * @author carles.bellver@cent.uji.es
  * @author Carles Bellver <carles.bellver@cent.uji.es>
+ * @author daniel@6temes.cat
  */
 $lang['menu']                  = 'Paràmetres de configuració';
 $lang['error']                 = 'Els paràmetres no s\'han pogut actualitzar per causa d\'un valor incorrecte Reviseu els canvis i torneu a enviar-los.<br />Els valors incorrectes es ressaltaran amb un marc vermell.';
@@ -28,6 +29,8 @@ $lang['_anti_spam']            = 'Paràmetres anti-brossa';
 $lang['_editing']              = 'Paràmetres d\'edició';
 $lang['_links']                = 'Paràmetres d\'enllaços';
 $lang['_media']                = 'Paràmetres de mitjans';
+$lang['_notifications']        = 'Paràmetres de notificació';
+$lang['_syndication']          = 'Paràmetres de sindicació';
 $lang['_advanced']             = 'Paràmetres avançats';
 $lang['_network']              = 'Paràmetres de xarxa';
 $lang['_plugin_sufix']         = 'Paràmetres de connectors';
@@ -35,25 +38,29 @@ $lang['_template_sufix']       = 'Paràmetres de plantilla';
 $lang['_msg_setting_undefined'] = 'Falten metadades de paràmetre.';
 $lang['_msg_setting_no_class'] = 'Falta classe de paràmetre.';
 $lang['_msg_setting_no_default'] = 'No hi ha valor per defecte.';
-$lang['fmode']                 = 'Mode de creació de fitxers';
-$lang['dmode']                 = 'Mode de creació de directoris';
+$lang['title']                 = 'Títol del wiki';
+$lang['start']                 = 'Nom de la pàgina d\'inici';
 $lang['lang']                  = 'Idioma';
+$lang['template']              = 'Plantilla';
+$lang['tagline']               = 'Lema (si la plantilla ho suporta)';
+$lang['sidebar']               = 'Nom de la barra lateral (si la plantilla ho suporta). Si ho deixeu buit, la barra lateral es deshabilitarà.';
+$lang['license']               = 'Amb quina llicència voleu publicar el contingut?';
+$lang['savedir']               = 'Directori per desar les dades';
 $lang['basedir']               = 'Directori base';
 $lang['baseurl']               = 'URL base';
-$lang['savedir']               = 'Directori per desar les dades';
-$lang['start']                 = 'Nom de la pàgina d\'inici';
-$lang['title']                 = 'Títol del wiki';
-$lang['template']              = 'Plantilla';
-$lang['license']               = 'Amb quina llicència voleu publicar el contingut?';
-$lang['fullpath']              = 'Mostra el camí complet de les pàgines al peu';
+$lang['cookiedir']             = 'Adreça per a les galetes. Si ho deixeu en blanc, es farà servir la URL base.';
+$lang['dmode']                 = 'Mode de creació de directoris';
+$lang['fmode']                 = 'Mode de creació de fitxers';
+$lang['allowdebug']            = 'Permet depuració <strong>inhabiliteu si no és necessari</strong>';
 $lang['recent']                = 'Canvis recents';
+$lang['recent_days']           = 'Quantitat de canvis recents que es mantenen (dies)';
 $lang['breadcrumbs']           = 'Nombre d\'engrunes';
 $lang['youarehere']            = 'Camí d\'engrunes jeràrquic';
+$lang['fullpath']              = 'Mostra el camí complet de les pàgines al peu';
 $lang['typography']            = 'Substitucions tipogràfiques';
-$lang['htmlok']                = 'Permet HTML incrustat';
-$lang['phpok']                 = 'Permet PHP incrustat';
 $lang['dformat']               = 'Format de data (vg. la funció PHP <a href="http://www.php.net/strftime">strftime</a>)';
 $lang['signature']             = 'Signatura';
+$lang['showuseras']            = 'Què cal visualitzar quan es mostra el darrer usuari que ha editat la pàgina';
 $lang['toptoclevel']           = 'Nivell superior per a la taula de continguts';
 $lang['tocminheads']           = 'Quantitat mínima d\'encapçalaments que determina si es construeix o no la taula de continguts.';
 $lang['maxtoclevel']           = 'Nivell màxim per a la taula de continguts';
@@ -61,15 +68,8 @@ $lang['maxseclevel']           = 'Nivell màxim d\'edició de seccions';
 $lang['camelcase']             = 'Utilitza CamelCase per als enllaços';
 $lang['deaccent']              = 'Noms de pàgina nets';
 $lang['useheading']            = 'Utilitza el primer encapçalament per als noms de pàgina';
-$lang['refcheck']              = 'Comprova la referència en els fitxers de mitjans';
-$lang['refshow']               = 'Nombre de referències de mitjans per mostrar';
-$lang['allowdebug']            = 'Permet depuració <strong>inhabiliteu si no és necessari</strong>';
-$lang['usewordblock']          = 'Bloca brossa per llista de paraules';
-$lang['indexdelay']            = 'Retard abans d\'indexar (segons)';
-$lang['relnofollow']           = 'Utilitza rel="nofollow" en enllaços externs';
-$lang['mailguard']             = 'Ofusca les adreces de correu';
-$lang['iexssprotect']          = 'Comprova codi HTML o Javascript maligne en els fitxers penjats';
-$lang['showuseras']            = 'Què cal visualitzar quan es mostra el darrer usuari que ha editat la pàgina';
+$lang['sneaky_index']          = 'Per defecte, DokuWiki mostrarà tots els espai en la visualització d\'índex. Si activeu aquest paràmetre, s\'ocultaran aquells espais en els quals l\'usuari no té accés de lectura. Això pot fer que s\'ocultin subespais que sí que són accessibles. En algunes configuracions ACL pot fer que l\'índex resulti inutilitzable.';
+$lang['hidepages']             = 'Oculta pàgines coincidents (expressions regulars)';
 $lang['useacl']                = 'Utilitza llistes de control d\'accés';
 $lang['autopasswd']            = 'Generació automàtica de contrasenyes';
 $lang['authtype']              = 'Rerefons d\'autenticació';
@@ -78,54 +78,60 @@ $lang['defaultgroup']          = 'Grup per defecte';
 $lang['superuser']             = 'Superusuari: un grup o usuari amb accés complet a totes les pàgines i funcions independentment dels paràmetres ACL';
 $lang['manager']               = 'Administrador: un grup o usuari amb accés a certes funcions d\'administració';
 $lang['profileconfirm']        = 'Confirma amb contrasenya els canvis en el perfil';
+$lang['rememberme']            = 'Permet galetes de sessió permanents ("recorda\'m")';
 $lang['disableactions']        = 'Inhabilita accions DokuWiki';
 $lang['disableactions_check']  = 'Revisa';
 $lang['disableactions_subscription'] = 'Subscripció/cancel·lació';
 $lang['disableactions_wikicode'] = 'Mostra/exporta font';
 $lang['disableactions_other']  = 'Altres accions (separades per comes)';
-$lang['sneaky_index']          = 'Per defecte, DokuWiki mostrarà tots els espai en la visualització d\'índex. Si activeu aquest paràmetre, s\'ocultaran aquells espais en els quals l\'usuari no té accés de lectura. Això pot fer que s\'ocultin subespais que sí que són accessibles. En algunes configuracions ACL pot fer que l\'índex resulti inutilitzable.';
 $lang['auth_security_timeout'] = 'Temps d\'espera de seguretat en l\'autenticació (segons)';
 $lang['securecookie']          = 'Les galetes que s\'han creat via HTTPS, només s\'han d\'enviar des del navegador per HTTPS? Inhabiliteu aquesta opció si només l\'inici de sessió del wiki es fa amb SSL i la navegació del wiki es fa sense seguretat.';
-$lang['updatecheck']           = 'Comprova actualitzacions i avisos de seguretat. DokuWiki necessitarà contactar amb update.dokuwiki.org per utilitzar aquesta característica.';
-$lang['userewrite']            = 'Utilitza URL nets';
-$lang['useslash']              = 'Utilitza la barra / com a separador d\'espais en els URL';
+$lang['usewordblock']          = 'Bloca brossa per llista de paraules';
+$lang['relnofollow']           = 'Utilitza rel="nofollow" en enllaços externs';
+$lang['indexdelay']            = 'Retard abans d\'indexar (segons)';
+$lang['mailguard']             = 'Ofusca les adreces de correu';
+$lang['iexssprotect']          = 'Comprova codi HTML o Javascript maligne en els fitxers penjats';
 $lang['usedraft']              = 'Desa automàticament un esborrany mentre s\'edita';
-$lang['sepchar']               = 'Separador de paraules en els noms de pàgina';
-$lang['canonical']             = 'Utilitza URL canònics complets';
-$lang['autoplural']            = 'Comprova formes plurals en els enllaços';
-$lang['compression']           = 'Mètode de compressió per als fitxers de les golfes';
-$lang['cachetime']             = 'Durada màxima de la memòria cau (segons)';
+$lang['htmlok']                = 'Permet HTML incrustat';
+$lang['phpok']                 = 'Permet PHP incrustat';
 $lang['locktime']              = 'Durada màxima dels fitxers de bloqueig (segons)';
-$lang['fetchsize']             = 'Mida màxima (bytes) que fetch.php pot baixar d\'un lloc extern';
-$lang['notify']                = 'Envia notificacions de canvis a aquesta adreça de correu';
-$lang['registernotify']        = 'Envia informació sobre nous usuaris registrats a aquesta adreça de correu';
-$lang['mailfrom']              = 'Adreça de correu remitent per a missatges automàtics';
-$lang['gzip_output']           = 'Codifica contingut xhtml com a gzip';
-$lang['gdlib']                 = 'Versió GD Lib';
-$lang['im_convert']            = 'Camí de la utilitat convert d\'ImageMagick';
-$lang['jpg_quality']           = 'Qualitat de compressió JPEG (0-100)';
-$lang['subscribers']           = 'Habilita la subscripció a pàgines';
-$lang['compress']              = 'Sortida CSS i Javascript compacta';
-$lang['hidepages']             = 'Oculta pàgines coincidents (expressions regulars)';
-$lang['send404']               = 'Envia "HTTP 404/Page Not Found" per a les pàgines inexistents';
-$lang['sitemap']               = 'Genera mapa del lloc en format Google (dies)';
-$lang['broken_iua']            = 'No funciona en el vostre sistema la funció ignore_user_abort? Això podria malmetre l\'índex de cerques. Amb IIS+PHP/CGI se sap que no funciona. Vg. <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> per a més informació.';
-$lang['xsendfile']             = 'Utilitza la capçalera X-Sendfile perquè el servidor web distribueixi fitxers estàtics. No funciona amb tots els servidors web.';
-$lang['renderer_xhtml']        = 'Renderitzador que cal utilitzar per a la sortida principal (xhtml) del wiki';
-$lang['renderer__core']        = '%s (ànima del dokuwiki)';
-$lang['renderer__plugin']      = '%s (connector)';
-$lang['rememberme']            = 'Permet galetes de sessió permanents ("recorda\'m")';
-$lang['rss_type']              = 'Tipus de canal XML';
-$lang['rss_linkto']            = 'Destinació dels enllaços en el canal XML';
-$lang['rss_content']           = 'Què es mostrarà en els elements del canal XML?';
-$lang['rss_update']            = 'Interval d\'actualització del canal XML (segons)';
-$lang['recent_days']           = 'Quantitat de canvis recents que es mantenen (dies)';
-$lang['rss_show_summary']      = 'Mostra resum en els títols del canal XML';
+$lang['cachetime']             = 'Durada màxima de la memòria cau (segons)';
 $lang['target____wiki']        = 'Finestra de destinació en enllaços interns';
 $lang['target____interwiki']   = 'Finestra de destinació en enllaços interwiki';
 $lang['target____extern']      = 'Finestra de destinació en enllaços externs';
 $lang['target____media']       = 'Finestra de destinació en enllaços de mitjans';
 $lang['target____windows']     = 'Finestra de destinació en enllaços de Windows';
+$lang['refcheck']              = 'Comprova la referència en els fitxers de mitjans';
+$lang['refshow']               = 'Nombre de referències de mitjans per mostrar';
+$lang['gdlib']                 = 'Versió GD Lib';
+$lang['im_convert']            = 'Camí de la utilitat convert d\'ImageMagick';
+$lang['jpg_quality']           = 'Qualitat de compressió JPEG (0-100)';
+$lang['fetchsize']             = 'Mida màxima (bytes) que fetch.php pot baixar d\'un lloc extern';
+$lang['subscribers']           = 'Habilita la subscripció a pàgines';
+$lang['notify']                = 'Envia notificacions de canvis a aquesta adreça de correu';
+$lang['registernotify']        = 'Envia informació sobre nous usuaris registrats a aquesta adreça de correu';
+$lang['mailfrom']              = 'Adreça de correu remitent per a missatges automàtics';
+$lang['sitemap']               = 'Genera mapa del lloc en format Google (dies)';
+$lang['rss_type']              = 'Tipus de canal XML';
+$lang['rss_linkto']            = 'Destinació dels enllaços en el canal XML';
+$lang['rss_content']           = 'Què es mostrarà en els elements del canal XML?';
+$lang['rss_update']            = 'Interval d\'actualització del canal XML (segons)';
+$lang['rss_show_summary']      = 'Mostra resum en els títols del canal XML';
+$lang['updatecheck']           = 'Comprova actualitzacions i avisos de seguretat. DokuWiki necessitarà contactar amb update.dokuwiki.org per utilitzar aquesta característica.';
+$lang['userewrite']            = 'Utilitza URL nets';
+$lang['useslash']              = 'Utilitza la barra / com a separador d\'espais en els URL';
+$lang['sepchar']               = 'Separador de paraules en els noms de pàgina';
+$lang['canonical']             = 'Utilitza URL canònics complets';
+$lang['autoplural']            = 'Comprova formes plurals en els enllaços';
+$lang['compression']           = 'Mètode de compressió per als fitxers de les golfes';
+$lang['gzip_output']           = 'Codifica contingut xhtml com a gzip';
+$lang['compress']              = 'Sortida CSS i Javascript compacta';
+$lang['send404']               = 'Envia "HTTP 404/Page Not Found" per a les pàgines inexistents';
+$lang['broken_iua']            = 'No funciona en el vostre sistema la funció ignore_user_abort? Això podria malmetre l\'índex de cerques. Amb IIS+PHP/CGI se sap que no funciona. Vg. <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a> per a més informació.';
+$lang['xsendfile']             = 'Utilitza la capçalera X-Sendfile perquè el servidor web distribueixi fitxers estàtics. No funciona amb tots els servidors web.';
+$lang['renderer_xhtml']        = 'Renderitzador que cal utilitzar per a la sortida principal (xhtml) del wiki';
+$lang['renderer__core']        = '%s (ànima del dokuwiki)';
+$lang['renderer__plugin']      = '%s (connector)';
 $lang['proxy____host']         = 'Nom del servidor intermediari';
 $lang['proxy____port']         = 'Port del servidor intermediari';
 $lang['proxy____user']         = 'Nom d\'usuari del servidor intermediari';
