@@ -1,23 +1,22 @@
 <?php
 /**
- * korean language file
+ * Korean language file
  *
- * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
+ * @license GPL 2 (http://www.gnu.org/licenses/gpl.html)
  * @author jk Lee
  * @author dongnak@gmail.com
  * @author Song Younghwan <purluno@gmail.com>
- * @author SONG Younghwan <purluno@gmail.com>
- * @author Seung-Chul Yoo  <dryoo@live.com>
+ * @author Seung-Chul Yoo <dryoo@live.com>
  * @author erial2@gmail.com
  * @author Myeongjin <aranet100@gmail.com>
  */
 $lang['menu']                  = '환경 설정';
-$lang['error']                 = '잘못된 값 때문에 설정을 변경할 수 없습니다. 수정한 값을 검토하고 확인을 누르세요.
+$lang['error']                 = '잘못된 값 때문에 설정을 바꿀 수 없습니다. 수정한 값을 검토하고 확인을 누르세요.
 <br />잘못된 값은 빨간 선으로 둘러싸여 있습니다.';
-$lang['updated']               = '설정이 성공적으로 변경되었습니다.';
-$lang['nochoice']              = '(다른 선택이 불가능합니다.)';
+$lang['updated']               = '설정이 성공적으로 바뀌었습니다.';
+$lang['nochoice']              = '(다른 선택이 불가능합니다)';
 $lang['locked']                = '환경 설정 파일을 수정할 수 없습니다. 의도한 행동이 아니라면,<br />
-파일 이름과 권한이 맞는지 확인하기 바랍니다. ';
+파일 이름과 권한이 맞는지 확인하세요.';
 $lang['danger']                = '위험: 이 옵션을 잘못 수정하면 환경설정 메뉴를 사용할 수 없을 수도 있습니다.';
 $lang['warning']               = '경고: 이 옵션을 잘못 수정하면 잘못 동작할 수 있습니다.';
 $lang['security']              = '보안 경고: 이 옵션은 보안에 위험이 있을 수 있습니다.';
@@ -39,27 +38,27 @@ $lang['_advanced']             = '고급 설정';
 $lang['_network']              = '네트워크 설정';
 $lang['_plugin_sufix']         = '플러그인 설정';
 $lang['_template_sufix']       = '템플릿 설정';
-$lang['_msg_setting_undefined'] = '설정되지 않은 메타데이터.';
-$lang['_msg_setting_no_class'] = '설정되지 않은 클래스.';
-$lang['_msg_setting_no_default'] = '기본값 없음.';
+$lang['_msg_setting_undefined'] = '설정된 메타데이터가 없습니다.';
+$lang['_msg_setting_no_class'] = '설정된 클래스가 없습니다.';
+$lang['_msg_setting_no_default'] = '기본값이 없습니다.';
 $lang['title']                 = '위키 제목 (위키 이름)';
 $lang['start']                 = '각 이름공간에서 사용할 시작 문서 이름';
 $lang['lang']                  = '인터페이스 언어';
 $lang['template']              = '템플릿 (위키 디자인)';
 $lang['tagline']               = '태그 라인 (템플릿이 지원할 때에 한함)';
-$lang['sidebar']               = '사이드바 문서 이름 (템플릿이 지원할 때에 한함). 비워두면 사이드바를 비활성화';
+$lang['sidebar']               = '사이드바 문서 이름 (템플릿이 지원할 때에 한함), 비워두면 사이드바를 비활성화';
 $lang['license']               = '콘텐츠에 어떤 라이선스를 적용하겠습니까?';
 $lang['savedir']               = '데이타 저장 디렉토리';
 $lang['basedir']               = '서버 경로 (예를 들어 <code>/dokuwiki/</code>). 자동 감지를 하려면 비우세요.';
 $lang['baseurl']               = '서버 URL (예를 들어 <code>http://www.yourserver.com</code>). 자동 감지를 하려면 비우세요.';
 $lang['cookiedir']             = '쿠키 위치. 비워두면 기본 URL 위치로 지정됩니다.';
-$lang['dmode']                 = '디렉토리 생성 모드';
-$lang['fmode']                 = '파일 생성 모드';
-$lang['allowdebug']            = '디버그 허용 <b>필요하지 않으면 금지!</b>';
+$lang['dmode']                 = '디렉토리 만들기 모드';
+$lang['fmode']                 = '파일 만들기 모드';
+$lang['allowdebug']            = '디버그 허용 <b>필요하지 않으면 비활성화할 것!</b>';
 $lang['recent']                = '최근 바뀐 문서당 항목 수';
-$lang['recent_days']           = '최근 바뀐 문서 기준 시간 (날짜)';
-$lang['breadcrumbs']           = '위치 "추적" 수. 0으로 설정하면 비활성화함.';
-$lang['youarehere']            = '계층형 위치 추적 (다음 위의 옵션을 비활성화하고 싶습니다)';
+$lang['recent_days']           = '최근 바뀐 문서 기준 시간 (일)';
+$lang['breadcrumbs']           = '위치 "추적" 수. 0으로 설정하면 비활성화합니다.';
+$lang['youarehere']            = '계층형 위치 추적 (다음 위의 옵션을 비활성화하게 됩니다)';
 $lang['fullpath']              = '문서 하단에 전체 경로 보여주기';
 $lang['typography']            = '기호 대체';
 $lang['dformat']               = '날짜 형식 (PHP <a href="http://www.php.net/strftime">strftime</a> 기능 참고)';
@@ -80,21 +79,21 @@ $lang['autopasswd']            = '자동으로 만들어진 비밀번호';
 $lang['authtype']              = '인증 백-엔드';
 $lang['passcrypt']             = '비밀번호 암호화 방법';
 $lang['defaultgroup']          = '기본 그룹, 모든 새 사용자는 이 그룹에 속합니다';
-$lang['superuser']             = '슈퍼 유저 - ACL 설정과 상관없이 모든 문서와 기능에 대한 전체 접근 권한을 가진 그룹이나 사용자. 사용자1,@그룹1,사용자2 쉼표로 구분한 목록';
-$lang['manager']               = '관리자 - 관리 기능을 사용할 수 있는 그룹이나 사용자. 사용자1,@그룹1,사용자2 쉼표로 구분한 목록';
+$lang['superuser']             = '슈퍼 유저 - ACL 설정과 상관없이 모든 문서와 기능에 대한 전체 접근 권한을 가진 그룹이나 사용자 또는 사용자1,@그룹1,사용자2 쉼표로 구분한 목록';
+$lang['manager']               = '관리자 - 관리 기능을 사용할 수 있는 그룹이나 사용자 또는 사용자1,@그룹1,사용자2 쉼표로 구분한 목록';
 $lang['profileconfirm']        = '개인 정보를 바꿀 때 비밀번호 다시 확인';
 $lang['rememberme']            = '항상 로그인 정보 저장 허용 (기억하기)';
 $lang['disableactions']        = 'DokuWiki 활동 비활성화';
 $lang['disableactions_check']  = '검사';
-$lang['disableactions_subscription'] = '구독 신청/해지';
-$lang['disableactions_wikicode'] = '내용 보기/원시 내보대기';
+$lang['disableactions_subscription'] = '구독 신청/구독 취소';
+$lang['disableactions_wikicode'] = '내용 보기/원본 내보내기';
 $lang['disableactions_other']  = '다른 활동 (쉼표로 구분)';
 $lang['auth_security_timeout'] = '인증 보안 초과 시간 (초)';
 $lang['securecookie']          = 'HTTPS로 보내진 쿠키는 HTTPS에만 적용 할까요? 위키의 로그인 페이지만 SSL로 암호화하고 위키 문서는 그렇지 않은 경우 비활성화 합니다.';
-$lang['remote']                = '원격 API를 활성화 합니다. 이 항목을 허용하면 XML-RPC 및 기타 메카니즘을 통해 다른 어플리케이션으로 접근가능합니다.';
+$lang['remote']                = '원격 API를 활성화 합니다. 이 항목을 허용하면 XML-RPC 및 기타 메카니즘을 통해 다른 어플리케이션으로 접근 가능합니다.';
 $lang['remoteuser']            = '이 항목에 입력된 쉼표로 나눠진 그룹이나 사용자에게 원격 API 접근을 제한합니다. 빈칸으로 두면 모두에게 허용합니다.';
 $lang['usewordblock']          = '금지 단어를 사용해 스팸 막기';
-$lang['relnofollow']           = '외부 링크에 rel="nofollow" 사용';
+$lang['relnofollow']           = '바깥 링크에 rel="nofollow" 사용';
 $lang['indexdelay']            = '색인 연기 시간 (초)';
 $lang['mailguard']             = '이메일 주소를 알아볼 수 없게 하기';
 $lang['iexssprotect']          = '올린 파일의 악성 자바스크립트, HTML 코드 가능성 여부를 검사';
@@ -105,29 +104,29 @@ $lang['locktime']              = '최대 파일 잠금 시간(초)';
 $lang['cachetime']             = '최대 캐시 생존 시간 (초)';
 $lang['target____wiki']        = '내부 링크에 대한 타겟 창';
 $lang['target____interwiki']   = '인터위키 링크에 대한 타겟 창';
-$lang['target____extern']      = '외부 링크에 대한 타겟 창';
+$lang['target____extern']      = '바깥 링크에 대한 타겟 창';
 $lang['target____media']       = '미디어 링크에 대한 타겟 창';
 $lang['target____windows']     = '창 링크에 대한 타겟 창';
-$lang['mediarevisions']        = '미디어 버전 관리를 사용하겠습니까?';
+$lang['mediarevisions']        = '미디어 판 관리를 사용하겠습니까?';
 $lang['refcheck']              = '미디어 파일을 삭제하기 전에 사용하고 있는지 검사';
 $lang['refshow']               = '위의 설정이 활성화되었을 때 보여줄 미디어 참고 수';
 $lang['gdlib']                 = 'GD 라이브러리 버전';
 $lang['im_convert']            = 'ImageMagick 변환 도구 위치';
 $lang['jpg_quality']           = 'JPG 압축 품질 (0-100)';
-$lang['fetchsize']             = 'fetch.php가 외부에서 다운로드할 수도 있는 최대 크기 (바이트)';
+$lang['fetchsize']             = 'fetch.php가 바깥에서 다운로드할 수도 있는 최대 크기 (바이트)';
 $lang['subscribers']           = '사용자가 이메일로 문서 바뀜에 구독하도록 허용';
-$lang['subscribe_time']        = '구독 목록과 요약이 보내질 경과 시간 (초); 이 것은 recent_days에서 설정된 시간보다 작아야 합니다.';
+$lang['subscribe_time']        = '구독 목록과 요약이 보내질 경과 시간 (초); recent_days에서 설정된 시간보다 작아야 합니다.';
 $lang['notify']                = '항상 이 이메일 주소로 바뀜 알림을 보냄';
 $lang['registernotify']        = '항상 새 사용자한테 이 이메일 주소로 정보를 보냄';
 $lang['mailfrom']              = '자동으로 보내지는 메일 발신자';
 $lang['mailprefix']            = '자동으로 보내지는 메일의 제목 말머리 내용. 비웠을 경우 위키 제목 사용';
-$lang['htmlmail']              = '용량은 조금 더 크지만 보기 좋은 HTML 태그가 포함된 메일을 발송합니다. 텍스트만의 메일을 보내고자하면 비활성화하세요.';
-$lang['sitemap']               = '구글 사이트맵 생성 (날짜). 0일 경우 비활성화';
+$lang['htmlmail']              = '용량은 조금 더 크지만 보기 좋은 HTML 태그가 포함된 메일을 보냅니다. 텍스트만의 메일을 보내고자하면 비활성화하세요.';
+$lang['sitemap']               = '구글 사이트맵 생성 날짜 빈도. 0일 경우 비활성화합니다';
 $lang['rss_type']              = 'XML 피드 타입';
 $lang['rss_linkto']            = 'XML 피드 링크 정보';
-$lang['rss_content']           = 'XML 피드 항목에 표시되는 내용은?';
+$lang['rss_content']           = 'XML 피드 항목에 표시되는 내용은 무엇입니까?';
 $lang['rss_update']            = 'XML 피드 업데이트 주기 (초)';
-$lang['rss_show_summary']      = 'XML 피드 제목에서 요약정보 보여주기';
+$lang['rss_show_summary']      = 'XML 피드 제목에서 요약 보여주기';
 $lang['rss_media']             = '어떤 규격으로 XML 피드를 받아보시겠습니까?';
 $lang['updatecheck']           = '업데이트와 보안 문제를 검사할까요? 이 기능을 사용하려면 DokuWiki를 update.dokuwiki.org에 연결해야 합니다.';
 $lang['userewrite']            = '멋진 URL 사용';
@@ -141,13 +140,12 @@ $lang['gzip_output']           = 'xhml 내용 gzip 압축 사용';
 $lang['compress']              = '최적화된 CSS, 자바스크립트 출력';
 $lang['cssdatauri']            = '그림이 렌더링될 최대 용량 크기를 CSS에 규정해야 HTTP 요청 헤더 오버헤드 크기를 감소시킬 수 있습니다. 이 기술은 IE 7 이하에서는 작동하지 않습니다! <code>400</code>에서 <code>600</code> 정도면 좋은 효율을 가져옵니다. <code>0</code>로 지정할 경우 비활성화 됩니다.';
 $lang['send404']               = '존재하지 않는 페이지에 대해 "HTTP 404/Page Not Found" 응답';
-$lang['broken_iua']            = '설치된 시스템에서 ignore_user_abort 기능에 문제가 있으면 색인이 정상적으로 동작하지 않습니다. 이 기능이 IIS+PHP/CGI에서 문제가 있는 것으로 알려졌습니다. 자세한 정보는 <a href="http://bugs.splitbrain.org/?do=details&amp;task_id=852">Bug 852</a>를 참고하기 바랍니다.';
-$lang['xsendfile']             = '웹 서버 static 파일 전송 지원을 위해 X-Sendfile 헤더를 사용한다면 이 옵션을 사용합니다.
-웹 서버가 이 기능을 지원해야 합니다.';
+$lang['broken_iua']            = '설치된 시스템에서 ignore_user_abort 기능에 문제가 있습니까? 문제가 있다면 색인이 정상적으로 동작하지 않습니다. 이 기능이 IIS+PHP/CGI에서 문제가 있는 것으로 알려졌습니다. 자세한 정보는 <a href="http://bugs.dokuwiki.org/?do=details&amp;task_id=852">버그 852</a>를 참고하시기 바랍니다.';
+$lang['xsendfile']             = '웹 서버가 정적 파일을 제공하도록 X-Sendfile 헤더를 사용하겠습니까? 웹 서버가 이 기능을 지원해야 합니다.';
 $lang['renderer_xhtml']        = '주 (xhtml) 위키 출력 처리기';
 $lang['renderer__core']        = '%s (DokuWiki 내부 기능)';
 $lang['renderer__plugin']      = '%s (플러그인)';
-$lang['dnslookups']            = '이 옵션을 활성화하면 도쿠위키가 문서를 수정하는 사용자의 호스트 네임과 원격 IP 주소를 확인합니다. 서버가 느리거나, DNS를 운영하지 않거나 이 기능을 원치 않으면 비활성화 시켜주세요.';
+$lang['dnslookups']            = '이 옵션을 활성화하면 DokuWiki가 문서를 수정하는 사용자의 호스트 네임과 원격 IP 주소를 확인합니다. 서버가 느리거나, DNS를 운영하지 않거나 이 기능을 원치 않으면 비활성화하세요';
 $lang['proxy____host']         = '프록시 서버 이름';
 $lang['proxy____port']         = '프록시 서버 포트';
 $lang['proxy____user']         = '프록시 사용자 이름';
@@ -167,7 +165,7 @@ $lang['typography_o_2']        = '모든 가능한 인용 부호 (동작 안될
 $lang['userewrite_o_0']        = '사용 안함';
 $lang['userewrite_o_1']        = '.htaccess';
 $lang['userewrite_o_2']        = 'DokuWiki 내부 기능';
-$lang['deaccent_o_0']          = '사용 안함';
+$lang['deaccent_o_0']          = '끄기';
 $lang['deaccent_o_1']          = '악센트 제거';
 $lang['deaccent_o_2']          = '라틴문자화';
 $lang['gdlib_o_0']             = 'GD 라이브러리 사용 불가';
@@ -194,8 +192,8 @@ $lang['xsendfile_o_1']         = '비공개 lighttpd 헤더 (1.5 이전 버전)'
 $lang['xsendfile_o_2']         = '표준 X-Sendfile 헤더';
 $lang['xsendfile_o_3']         = '비공개 Nginx X-Accel-Redirect 헤더';
 $lang['showuseras_o_loginname'] = '로그인 이름';
-$lang['showuseras_o_username'] = '사용자 이름';
-$lang['showuseras_o_email']    = '사용자 이메일 주소 (메일 주소 보호 설정에 따라 안보일 수 있음)';
+$lang['showuseras_o_username'] = '사용자의 전체 이름';
+$lang['showuseras_o_email']    = '사용자의 이메일 주소 (메일 주소 보호 설정에 따라 안보일 수 있음)';
 $lang['showuseras_o_email_link'] = 'mailto: link로 표현될 사용자 이메일 주소';
 $lang['useheading_o_0']        = '아니오';
 $lang['useheading_o_navigation'] = '둘러보기에만';
