@@ -60,4 +60,4 @@ $lang['enabled']               = '%s 插件启用';
 $lang['notenabled']            = '%s插件启用失败，请检查文件权限。';
 $lang['disabled']              = '%s 插件禁用';
 $lang['notdisabled']           = '%s插件禁用失败，请检查文件权限。';
-$lang['packageinstalled']      = '插件  (%d plugin%s: %s) 已成功安装。';
+$lang['packageinstalled']      = '插件  (%d 插件: %s) 已成功安装。';
