@@ -10,11 +10,12 @@
  * @author Danny Lin
  * @author Shuo-Ting Jian <shoting@gmail.com>
  * @author syaoranhinata@gmail.com
+ * @author Ichirou Uchiki <syaoranhinata@gmail.com>
  */
-$lang['name']                  = '人氣回饋（載入可能需要一些時間）';
+$lang['name']                  = '人氣回饋 (可能需要一些時間載入) ';
 $lang['submit']                = '發送資料';
 $lang['autosubmit']            = '每月自動發送';
-$lang['submissionFailed']      = '由於以下原因，資料無法發送:';
-$lang['submitDirectly']        = '你可以利用以下的表單來發手動發送資料.';
-$lang['autosubmitError']       = '由於以下原因，上次自動發送失敗:';
+$lang['submissionFailed']      = '由於以下原因，資料無法發送：';
+$lang['submitDirectly']        = '你可以利用以下的表單來發手動發送資料。';
+$lang['autosubmitError']       = '由於以下原因，上次自動發送無法進行：';
 $lang['lastSent']              = '資料已發送';
