@@ -10,13 +10,14 @@
  * @author Danny Lin <danny0838@pchome.com.tw>
  * @author Shuo-Ting Jian <shoting@gmail.com>
  * @author syaoranhinata@gmail.com
+ * @author Ichirou Uchiki <syaoranhinata@gmail.com>
  */
 $lang['menu']                  = '還原管理';
 $lang['filter']                = '搜索包含垃圾訊息的頁面';
 $lang['revert']                = '還原選取的頁面';
-$lang['reverted']              = '%s 已還原為版本 %s';
+$lang['reverted']              = '%s 已還原成版本 %s';
 $lang['removed']               = '%s 已移除';
 $lang['revstart']              = '已開始還原操作。有可能需要很長時間。如果程式執行逾時，請嘗試分次還原少量內容。';
-$lang['revstop']               = '還原程序已成功完成。';
+$lang['revstop']               = '還原程序已完成。';
 $lang['note1']                 = '注意：搜尋區分大小寫';
-$lang['note2']                 = '注意：此頁面將被還原為最後一個不含垃圾訊息 <i>%s</i> 的版本。';
+$lang['note2']                 = '注意：我們將把此頁面還原作最後一個不含垃圾訊息 <i>%s</i> 的版本。';
