@@ -84,13 +84,13 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
      *
      * Usually you should only need the $match param.
      *
-     * @param   $match   string    The text matched by the patterns
-     * @param   $state   int       The lexer state for the match
-     * @param   $pos     int       The character position of the matched text
-     * @param   $handler Doku_Handler Reference to the Doku_Handler object
-     * @return  array              Return an array with all data you want to use in render
+     * @param   string       $match   The text matched by the patterns
+     * @param   int          $state   The lexer state for the match
+     * @param   int          $pos     The character position of the matched text
+     * @param   Doku_Handler $handler Reference to the Doku_Handler object
+     * @return  array Return an array with all data you want to use in render
      */
-    function handle($match, $state, $pos, &$handler){
+    function handle($match, $state, $pos, Doku_Handler &$handler){
         trigger_error('handle() not implemented in '.get_class($this), E_USER_WARNING);
     }
 
@@ -117,7 +117,7 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
      * @param   $data     array         data created by handler()
      * @return  boolean                 rendered correctly?
      */
-    function render($format, &$renderer, $data) {
+    function render($format, Doku_Renderer &$renderer, $data) {
         trigger_error('render() not implemented in '.get_class($this), E_USER_WARNING);
 
     }
@@ -226,56 +226,76 @@ class DokuWiki_Syntax_Plugin extends Doku_Parser_Mode {
       $this->localised = true;
     }
 
-  // configuration methods
-  /**
-   * getConf($setting)
-   *
-   * use this function to access plugin configuration variables
-   */
-  function getConf($setting){
+    // configuration methods
+    /**
+     * getConf($setting)
+     *
+     * use this function to access plugin configuration variables
+     */
+    function getConf($setting) {
 
-    if (!$this->configloaded){ $this->loadConfig(); }
+        if(!$this->configloaded) { $this->loadConfig(); }
 
-    return $this->conf[$setting];
-  }
-
-  /**
-   * loadConfig()
-   * merges the plugin's default settings with any local settings
-   * this function is automatically called through getConf()
-   */
-  function loadConfig(){
-    global $conf;
-
-    $defaults = $this->readDefaultSettings();
-    $plugin = $this->getPluginName();
-
-    foreach ($defaults as $key => $value) {
-      if (isset($conf['plugin'][$plugin][$key])) continue;
-      $conf['plugin'][$plugin][$key] = $value;
+        return $this->conf[$setting];
     }
 
-    $this->configloaded = true;
-    $this->conf =& $conf['plugin'][$plugin];
-  }
+    /**
+     * loadConfig()
+     * merges the plugin's default settings with any local settings
+     * this function is automatically called through getConf()
+     */
+    function loadConfig() {
+        global $conf;
 
-  /**
-   * read the plugin's default configuration settings from conf/default.php
-   * this function is automatically called through getConf()
-   *
-   * @return    array    setting => value
-   */
-  function readDefaultSettings() {
+        $defaults = $this->readDefaultSettings();
+        $plugin   = $this->getPluginName();
 
-    $path = DOKU_PLUGIN.$this->getPluginName().'/conf/';
-    $conf = array();
+        foreach($defaults as $key => $value) {
+            if(isset($conf['plugin'][$plugin][$key])) continue;
+            $conf['plugin'][$plugin][$key] = $value;
+        }
 
-    if (@file_exists($path.'default.php')) {
-      include($path.'default.php');
+        $this->configloaded = true;
+        $this->conf         =& $conf['plugin'][$plugin];
     }
 
-    return $conf;
-  }
+    /**
+     * read the plugin's default configuration settings from conf/default.php
+     * this function is automatically called through getConf()
+     *
+     * @return    array    setting => value
+     */
+    function readDefaultSettings() {
+
+        $path = DOKU_PLUGIN.$this->getPluginName().'/conf/';
+        $conf = array();
+
+        if(@file_exists($path.'default.php')) {
+            include($path.'default.php');
+        }
+
+        return $conf;
+    }
+
+    /**
+     * Loads a given helper plugin (if enabled)
+     *
+     * @author  Esther Brunner <wikidesign@gmail.com>
+     *
+     * @param   string $name   name of plugin to load
+     * @param   bool   $msg    if a message should be displayed in case the plugin is not available
+     *
+     * @return  object  helper plugin object
+     */
+    function loadHelper($name, $msg = true) {
+        if(!plugin_isdisabled($name)) {
+            $obj = plugin_load('helper', $name);
+        } else {
+            $obj = null;
+        }
+        if(is_null($obj) && $msg) msg("Helper plugin $name is not available or invalid.", -1);
+        return $obj;
+    }
 
     /**
      * Allow the plugin to prevent DokuWiki from reusing an instance
