@@ -9,9 +9,7 @@
  * @author Robert Bogenschneider <robog@gmx.de>
  * @author Erik Pedersen <erik pedersen@shaw.ca>
  * @author Erik Pedersen <erik.pedersen@shaw.ca>
- * @author Robert Bogenschneider <robog@GMX.de>
- * @author Robert BOGENSCHNEIDER <robog@gmx.de>
- * @author Robert BOGENSCHNEIDER <bogi@UEA.org>
+ * @author Robert Bogenschneider <bogi@uea.org>
  */
 $lang['menu']                  = 'Administrado de uzantoj';
 $lang['noauth']                = '(identiĝo de uzantoj ne disponeblas)';
@@ -20,7 +18,7 @@ $lang['badauth']               = 'tiu identiĝa procezo ne validas';
 $lang['user_id']               = 'Uzanto';
 $lang['user_pass']             = 'Pasvorto';
 $lang['user_name']             = 'Vera nomo';
-$lang['user_mail']             = 'Retadreso';
+$lang['user_mail']             = 'Retpoŝtadreso';
 $lang['user_groups']           = 'Grupoj';
 $lang['field']                 = 'Kampo';
 $lang['value']                 = 'Valoro';
@@ -35,22 +33,22 @@ $lang['search_prompt']         = 'Fari serĉon';
 $lang['clear']                 = 'Refari serĉan filtron';
 $lang['filter']                = 'Filtro';
 $lang['summary']               = 'Montriĝas uzantoj %1$d-%2$d el %3$d trovitaj. %4$d uzantoj entute.';
-$lang['nonefound']             = 'Neniu uzantoj troviĝas. %d uzantoj entute.';
-$lang['delete_ok']             = '%d uzantoj estis forigitaj';
+$lang['nonefound']             = 'Neniuj uzantoj troviĝas. %d uzantoj entute.';
+$lang['delete_ok']             = '%d uzantoj forigiĝis';
 $lang['delete_fail']           = '%d malsukcesis esti forigitaj.';
-$lang['update_ok']             = 'Tiu uzanto estis sukcese ĝisdatigita';
+$lang['update_ok']             = 'Tiu uzanto sukcese ĝisdatiĝis';
 $lang['update_fail']           = 'Malsukceso okazis por ĝisdatigi tiun uzanton';
 $lang['update_exists']         = 'Malsukceso okazis por ŝanĝi la nomon de tiu uzanto: la enmetita nomo (%s) jam ekzistas (ĉiuj aliaj ŝanĝoj estos aplikitaj)';
 $lang['start']                 = 'Ekigi';
 $lang['prev']                  = 'antaŭe';
 $lang['next']                  = 'sekve';
 $lang['last']                  = 'laste';
-$lang['edit_usermissing']      = 'La elektita uzanto ne estis trovita: tiu nomo povis esti forigita aŭ ŝanĝita aliloke.';
+$lang['edit_usermissing']      = 'La elektita uzanto ne troviĝis: tiu nomo povis esti forigita aŭ ŝanĝita aliloke.';
 $lang['user_notify']           = 'Avizi uzanton';
 $lang['note_notify']           = 'Avizantaj mesaĝoj estos sendataj nur se la uzanto ekhavos novan pasvorton.';
 $lang['note_group']            = 'Novaj uzantoj estos aldonitaj al la komuna grupo (%s) se neniu alia estos specifita.';
-$lang['note_pass']             = 'La pasvorto estos aŭtomate kreita se la kampo estos lasita malplena kaj \'aviso al uzantoj\' estos ebligita.';
-$lang['add_ok']                = 'La uzanto estis sukcese aldonita';
-$lang['add_fail']              = 'Malsukceso okazis por aldoni uzulon';
-$lang['notify_ok']             = 'Avizanta mesaĝo estis sendita';
+$lang['note_pass']             = 'La pasvorto estos aŭtomate kreita se la kampo estos lasita malplena kaj \'avizo al uzantoj\' estos ebligita.';
+$lang['add_ok']                = 'La uzanto sukcese aldoniĝis';
+$lang['add_fail']              = 'Ne eblis aldoni uzanton';
+$lang['notify_ok']             = 'Avizanta mesaĝo sendiĝis';
 $lang['notify_fail']           = 'La avizanta mesaĝo ne povis esti sendita';
