@@ -1,19 +1,18 @@
 <?php
 /**
- * korean language file
+ * Korean language file
  *
  * @author jk Lee
  * @author dongnak@gmail.com
  * @author Song Younghwan <purluno@gmail.com>
- * @author SONG Younghwan <purluno@gmail.com>
- * @author Seung-Chul Yoo  <dryoo@live.com>
+ * @author Seung-Chul Yoo <dryoo@live.com>
  * @author erial2@gmail.com
  * @author Myeongjin <aranet100@gmail.com>
  */
 $lang['menu']                  = '사용자 관리자';
-$lang['noauth']                = '(사용자 인증이 불가능합니다.)';
-$lang['nosupport']             = '(사용자 관리가 지원되지 않습니다.)';
-$lang['badauth']               = '잘못된 인증 메카니즘';
+$lang['noauth']                = '(사용자 인증이 불가능합니다)';
+$lang['nosupport']             = '(사용자 관리가 지원되지 않습니다)';
+$lang['badauth']               = '인증 메카니즘이 잘못되었습니다';
 $lang['user_id']               = '사용자';
 $lang['user_pass']             = '비밀번호';
 $lang['user_name']             = '실제 이름';
@@ -31,23 +30,23 @@ $lang['search']                = '찾기';
 $lang['search_prompt']         = '찾기 실행';
 $lang['clear']                 = '찾기 필터 초기화';
 $lang['filter']                = '필터';
-$lang['summary']               = '찾은 사용자 %3$d 중 %1$d-%2$d 보기. 전체 사용자 %4$d명.';
-$lang['nonefound']             = '찾은 사용자가 없습니다. 전체 사용자 %d명.';
+$lang['summary']               = '찾은 사용자 %3$d 중 %1$d-%2$d을(를) 봅니다. 전체 사용자는 %4$d명입니다.';
+$lang['nonefound']             = '찾은 사용자가 없습니다. 전체 사용자는 %d명입니다.';
 $lang['delete_ok']             = '사용자 %d명이 삭제되었습니다';
 $lang['delete_fail']           = '사용자 %d명의 삭제가 실패했습니다.';
-$lang['update_ok']             = '사용자 변경을 성공했습니다.';
-$lang['update_fail']           = '사용자 변경을 실패했습니다.';
-$lang['update_exists']         = '사용자 이름 변경이 실패했습니다. 사용자 이름(%s)이 이미 존재합니다. (다른 항목의 바뀜은 적용됩니다.)';
+$lang['update_ok']             = '사용자 정보를 성공적으로 바꾸었습니다';
+$lang['update_fail']           = '사용자 정보를 바꾸는 데 실패했습니다';
+$lang['update_exists']         = '사용자 이름을 바꾸는 데 실패했습니다. 사용자 이름(%s)이 이미 존재합니다. (다른 항목의 바뀜은 적용됩니다.)';
 $lang['start']                 = '시작';
 $lang['prev']                  = '이전';
 $lang['next']                  = '다음';
 $lang['last']                  = '마지막';
-$lang['edit_usermissing']      = '선택된 사용자를 찾을 수 없습니다. 사용자 이름이 삭제되거나 변경됐을 수도 있습니다.';
+$lang['edit_usermissing']      = '선택된 사용자를 찾을 수 없습니다. 사용자 이름이 삭제되거나 바뀌었을 수도 있습니다.';
 $lang['user_notify']           = '사용자에게 알림';
 $lang['note_notify']           = '사용자에게 새로운 비밀번호를 준 경우에만 알림 이메일이 보내집니다.';
 $lang['note_group']            = '새로운 사용자는 어떤 그룹도 설정하지 않은 경우에 기본 그룹(%s)에 추가됩니다.';
 $lang['note_pass']             = '사용자 통지가 지정되어 있을 때 필드에 아무 값도 입력하지 않으면 비밀번호가 자동으로 만들어집니다.';
-$lang['add_ok']                = '사용자가 성공적으로 추가되었습니다.';
-$lang['add_fail']              = '사용자 추가가 실패했습니다.';
-$lang['notify_ok']             = '알림 이메일이 성공적으로 발송되었습니다. ';
-$lang['notify_fail']           = '알림 이메일 발송이 실패했습니다.';
+$lang['add_ok']                = '사용자를 성공적으로 추가했습니다';
+$lang['add_fail']              = '사용자 추가를 실패했습니다';
+$lang['notify_ok']             = '알림 이메일을 성공적으로 보냈습니다';
+$lang['notify_fail']           = '알림 이메일을 보낼 수 없습니다';
